summaryrefslogtreecommitdiffstats
path: root/kpresenter
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:02:43 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:02:43 -0600
commitaea627236e4de24599c3e30617cf264c3c1b7d40 (patch)
tree467e13ca5a7eb0ab292259289ecc3572f53c5eae /kpresenter
parent786304c6211f35ddc4cdd54b7aa7985fef4a2e70 (diff)
downloadkoffice-aea627236e4de24599c3e30617cf264c3c1b7d40.tar.gz
koffice-aea627236e4de24599c3e30617cf264c3c1b7d40.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kpresenter')
-rw-r--r--kpresenter/KPrCanvas.cpp2
-rw-r--r--kpresenter/KPrCanvas.h4
-rw-r--r--kpresenter/KPrConfig.cpp6
-rw-r--r--kpresenter/KPrConfig.h2
-rw-r--r--kpresenter/KPrMSPresentationSetup.h2
-rw-r--r--kpresenter/KPrPresDurationDia.cpp4
-rw-r--r--kpresenter/KPrPresDurationDia.h4
-rw-r--r--kpresenter/KPrSideBar.cpp34
-rw-r--r--kpresenter/KPrSideBar.h6
-rw-r--r--kpresenter/KPrTextObject.cpp6
-rw-r--r--kpresenter/KPrTextObject.h4
-rw-r--r--kpresenter/KPrView.cpp414
-rw-r--r--kpresenter/KPrView.h414
-rw-r--r--kpresenter/KPrWebPresentation.cpp4
-rw-r--r--kpresenter/KPrWebPresentation.h4
15 files changed, 455 insertions, 455 deletions
diff --git a/kpresenter/KPrCanvas.cpp b/kpresenter/KPrCanvas.cpp
index 8c1d244c..358c852b 100644
--- a/kpresenter/KPrCanvas.cpp
+++ b/kpresenter/KPrCanvas.cpp
@@ -2306,7 +2306,7 @@ void KPrCanvas::setMouseSelectedObject(bool b)
void KPrCanvas::setupMenus()
{
// create right button presentation menu
- m_presMenu = new KPopupMenu();
+ m_presMenu = new TDEPopupMenu();
TQ_CHECK_PTR( m_presMenu );
m_presMenu->setCheckable( true );
m_presMenu->insertTitle( i18n( "Slide Show" ) );
diff --git a/kpresenter/KPrCanvas.h b/kpresenter/KPrCanvas.h
index e19911a7..ec42bfa0 100644
--- a/kpresenter/KPrCanvas.h
+++ b/kpresenter/KPrCanvas.h
@@ -49,7 +49,7 @@ class TQPainter;
class KTextEdit;
class KPrTextObject;
class KPrObject;
-class KPopupMenu;
+class TDEPopupMenu;
class TQResizeEvent;
class TQPaintEvent;
class TQDragEnterEvent;
@@ -791,7 +791,7 @@ private:
static const int KEY_SNAP_DISTANCE;
// variables
/// Popup menu used in presentation mode.
- KPopupMenu *m_presMenu;
+ TDEPopupMenu *m_presMenu;
bool showingLastSlide;
bool mousePressed;
bool drawContour;
diff --git a/kpresenter/KPrConfig.cpp b/kpresenter/KPrConfig.cpp
index e6e706cc..4009382c 100644
--- a/kpresenter/KPrConfig.cpp
+++ b/kpresenter/KPrConfig.cpp
@@ -798,8 +798,8 @@ void KPrConfigureDefaultDocPage::slotDefault()
void KPrConfigureDefaultDocPage::selectNewDefaultFont() {
TQStringList list;
- KFontChooser::getFontList(list, KFontChooser::SmoothScalableFonts);
- KFontDialog dlg( this, "Font Selector", false, true, list, true );
+ TDEFontChooser::getFontList(list, TDEFontChooser::SmoothScalableFonts);
+ TDEFontDialog dlg( this, "Font Selector", false, true, list, true );
dlg.setFont(*font);
int result = dlg.exec();
if (KDialog::Accepted == result) {
@@ -939,7 +939,7 @@ KPrConfigurePathPage::KPrConfigurePathPage( KPrView *_view, TQWidget *parent, ch
KPrDocument* doc = m_pView->kPresenterDoc();
config = KPrFactory::global()->config();
- m_pPathView = new KListView( this );
+ m_pPathView = new TDEListView( this );
m_pPathView->setResizeMode(TQListView::NoColumn);
m_pPathView->addColumn( i18n( "Type" ) );
m_pPathView->addColumn( i18n( "Path" ) );
diff --git a/kpresenter/KPrConfig.h b/kpresenter/KPrConfig.h
index 2616298a..b1696eb4 100644
--- a/kpresenter/KPrConfig.h
+++ b/kpresenter/KPrConfig.h
@@ -181,7 +181,7 @@ private slots:
private:
KPrView* m_pView;
TDEConfig* config;
- KListView* m_pPathView;
+ TDEListView* m_pPathView;
TQPushButton *m_modifyPath;
};
diff --git a/kpresenter/KPrMSPresentationSetup.h b/kpresenter/KPrMSPresentationSetup.h
index 6da45782..293971ce 100644
--- a/kpresenter/KPrMSPresentationSetup.h
+++ b/kpresenter/KPrMSPresentationSetup.h
@@ -34,7 +34,7 @@ class KPrView;
class KURLRequester;
class KColorButton;
-class KListView;
+class TDEListView;
class KIntNumInput;
class KLineEdit;
class KComboBox;
diff --git a/kpresenter/KPrPresDurationDia.cpp b/kpresenter/KPrPresDurationDia.cpp
index 67813eb1..2591e4c5 100644
--- a/kpresenter/KPrPresDurationDia.cpp
+++ b/kpresenter/KPrPresDurationDia.cpp
@@ -58,7 +58,7 @@ KPrPresDurationDia::KPrPresDurationDia( TQWidget *parent, const char *name,
void KPrPresDurationDia::setupSlideList( TQWidget *_page )
{
- slides = new KListView( _page );
+ slides = new TDEListView( _page );
slides->addColumn( i18n( "No." ) );
slides->addColumn( i18n( "Display Duration" ) );
slides->addColumn( i18n( "Slide Title" ) );
@@ -69,7 +69,7 @@ void KPrPresDurationDia::setupSlideList( TQWidget *_page )
for ( int i = doc->getPageNums() - 1; i >= 0; --i ) {
if ( doc->pageList().at( i )->isSlideSelected() ) {
- KListViewItem *item = new KListViewItem( slides );
+ TDEListViewItem *item = new TDEListViewItem( slides );
item->setPixmap( 0, KPBarIcon( "slide" ) );
item->setText( 0, TQString( "%1" ).arg( i + 1 ) );
item->setText( 1, *m_durationListString.at( i ) );
diff --git a/kpresenter/KPrPresDurationDia.h b/kpresenter/KPrPresDurationDia.h
index 1007955a..888cb9db 100644
--- a/kpresenter/KPrPresDurationDia.h
+++ b/kpresenter/KPrPresDurationDia.h
@@ -24,7 +24,7 @@
#include <kdialogbase.h>
class KPrDocument;
-class KListView;
+class TDEListView;
class TQLabel;
class KPrPresDurationDia : public KDialogBase
@@ -43,7 +43,7 @@ protected:
private:
KPrDocument *doc;
- KListView *slides;
+ TDEListView *slides;
TQLabel *label;
TQStringList m_durationListString;
diff --git a/kpresenter/KPrSideBar.h b/kpresenter/KPrSideBar.h
index 161ae88b..542e8c39 100644
--- a/kpresenter/KPrSideBar.h
+++ b/kpresenter/KPrSideBar.h
@@ -100,7 +100,7 @@ private:
int m_offsetY;
};
-class KPrOutline: public KListView, public KPrSideBarBase
+class KPrOutline: public TDEListView, public KPrSideBarBase
{
Q_OBJECT
@@ -109,7 +109,7 @@ public:
KPrOutline( TQWidget *parent, KPrDocument *d, KPrView *v );
~KPrOutline();
void setCurrentPage( int pg );
- TQSize sizeHint() const { return TQSize( 145, KListView::sizeHint().height() ); }
+ TQSize sizeHint() const { return TQSize( 145, TDEListView::sizeHint().height() ); }
void updateItem( int pagenr, bool sticky = false);
void addItem( int pos );
void moveItem( int oldPos, int newPos );
@@ -136,7 +136,7 @@ private slots:
void itemClicked( TQListViewItem *i );
void slotDropped( TQDropEvent *e, TQListViewItem *parent, TQListViewItem *target );
void rightButtonPressed( TQListViewItem *i, const TQPoint &pnt, int c );
- void slotContextMenu( KListView*, TQListViewItem *item, const TQPoint &p );
+ void slotContextMenu( TDEListView*, TQListViewItem *item, const TQPoint &p );
private:
TQListViewItem *m_movedItem, *m_movedAfter;
diff --git a/kpresenter/KPrTextObject.cpp b/kpresenter/KPrTextObject.cpp
index 6ae9bec0..d0782541 100644
--- a/kpresenter/KPrTextObject.cpp
+++ b/kpresenter/KPrTextObject.cpp
@@ -2211,14 +2211,14 @@ void KPrTextView::mouseReleaseEvent( TQMouseEvent *, const TQPoint & )
handleMouseReleaseEvent();
}
-void KPrTextView::showPopup( KPrView *view, const TQPoint &point, TQPtrList<KAction>& actionList )
+void KPrTextView::showPopup( KPrView *view, const TQPoint &point, TQPtrList<TDEAction>& actionList )
{
TQString word = wordUnderCursor( *cursor() );
view->unplugActionList( "datatools" );
view->unplugActionList( "datatools_link" );
view->unplugActionList( "spell_result_action" );
view->unplugActionList( "variable_action" );
- TQPtrList<KAction> &variableList = view->variableActionList();
+ TQPtrList<TDEAction> &variableList = view->variableActionList();
variableList.clear();
actionList.clear();
@@ -2259,7 +2259,7 @@ void KPrTextView::showPopup( KPrView *view, const TQPoint &point, TQPtrList<KAct
{
if ( singleWord )
{
- TQPtrList<KAction> actionCheckSpellList =view->listOfResultOfCheckWord( word );
+ TQPtrList<TDEAction> actionCheckSpellList =view->listOfResultOfCheckWord( word );
if ( actionCheckSpellList.count()>0)
{
view->plugActionList( "spell_result_action", actionCheckSpellList );
diff --git a/kpresenter/KPrTextObject.h b/kpresenter/KPrTextObject.h
index d843bdb3..8f164d73 100644
--- a/kpresenter/KPrTextObject.h
+++ b/kpresenter/KPrTextObject.h
@@ -258,7 +258,7 @@ public:
virtual void drawCursor( bool b );
const KoParagLayout & currentParagLayout() const { return m_paragLayout; }
- void showPopup( KPrView *view, const TQPoint &point, TQPtrList<KAction> &actionList );
+ void showPopup( KPrView *view, const TQPoint &point, TQPtrList<TDEAction> &actionList );
void insertVariable( int type, int subtype = 0 );
void insertCustomVariable( const TQString &name);
void insertLink(const TQString &_linkName, const TQString & hrefName);
@@ -307,7 +307,7 @@ protected:
KPrTextObject *m_kptextobj;
KPrCanvas *m_canvas;
KoParagLayout m_paragLayout;
- TQPtrList<KAction> m_actionList; // for the kodatatools
+ TQPtrList<TDEAction> m_actionList; // for the kodatatools
};
diff --git a/kpresenter/KPrView.cpp b/kpresenter/KPrView.cpp
index d6407823..ee68f7a5 100644
--- a/kpresenter/KPrView.cpp
+++ b/kpresenter/KPrView.cpp
@@ -2323,18 +2323,18 @@ void KPrView::setupActions()
actionEditPaste, TQT_SLOT( setEnabled( bool ) ) );
m_pKPresenterDoc->clipboardDataChanged(); // set paste's initial state
- actionEditDelete = new KAction( i18n( "&Delete" ), "editdelete", CTRL + TQt::Key_Delete,
+ actionEditDelete = new TDEAction( i18n( "&Delete" ), "editdelete", CTRL + TQt::Key_Delete,
TQT_TQOBJECT(this), TQT_SLOT( editDelete() ),
actionCollection(), "edit_delete" );
actionEditSelectAll = KStdAction::selectAll( TQT_TQOBJECT(this), TQT_SLOT( editSelectAll() ), actionCollection(), "edit_selectall" );
actionEditDeSelectAll= KStdAction::deselect( TQT_TQOBJECT(this), TQT_SLOT( editDeSelectAll()), actionCollection(), "edit_deselectall");
- actionEditCopyPage = new KAction( i18n( "Copy Slide" ), "editcopy",
+ actionEditCopyPage = new TDEAction( i18n( "Copy Slide" ), "editcopy",
0, TQT_TQOBJECT(this), TQT_SLOT( editCopyPage() ),
actionCollection(), "edit_copypage" );
- actionEditDuplicatePage = new KAction( i18n( "Duplicate Slide" ), "newslide",
+ actionEditDuplicatePage = new TDEAction( i18n( "Duplicate Slide" ), "newslide",
0, TQT_TQOBJECT(this), TQT_SLOT( editDuplicatePage() ),
actionCollection(), "edit_duplicatepage" );
- actionEditDelPage = new KAction( i18n( "Delete Slide" ), "delslide", 0,
+ actionEditDelPage = new TDEAction( i18n( "Delete Slide" ), "delslide", 0,
TQT_TQOBJECT(this), TQT_SLOT( editDelPage() ),
actionCollection(), "edit_delpage" );
@@ -2347,108 +2347,108 @@ void KPrView::setupActions()
if ( !m_pKPresenterDoc->isEmbedded() )
{
- actionViewShowSideBar = new KToggleAction( i18n("Show Sidebar"), 0,
+ actionViewShowSideBar = new TDEToggleAction( i18n("Show Sidebar"), 0,
TQT_TQOBJECT(this), TQT_SLOT( viewShowSideBar() ),
actionCollection(), "view_showsidebar" );
actionViewShowSideBar->setCheckedState(i18n("Hide Sidebar"));
- actionViewShowNoteBar = new KToggleAction( i18n("Show Notebar"), 0,
+ actionViewShowNoteBar = new TDEToggleAction( i18n("Show Notebar"), 0,
TQT_TQOBJECT(this), TQT_SLOT( viewShowNoteBar() ),
actionCollection(), "view_shownotebar" );
actionViewShowNoteBar->setCheckedState(i18n("Hide Notebar"));
}
- actionViewFormattingChars = new KToggleAction( i18n( "&Formatting Characters" ), 0,
+ actionViewFormattingChars = new TDEToggleAction( i18n( "&Formatting Characters" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotViewFormattingChars() ),
actionCollection(), "view_formattingchars" );
actionViewFormattingChars->setToolTip( i18n( "Toggle the display of non-printing characters." ) );
actionViewFormattingChars->setWhatsThis( i18n( "Toggle the display of non-printing characters.<br><br>When this is enabled, KPresenter shows you tabs, spaces, carriage returns and other non-printing characters." ) );
- actionViewSlideMaster = new KToggleAction( i18n( "Slide &Master" ), 0,
+ actionViewSlideMaster = new TDEToggleAction( i18n( "Slide &Master" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( viewSlideMaster() ),
actionCollection(), "view_master" );
- actionViewShowGuideLine= new KToggleAction( i18n( "Guide Lines" ), 0,
+ actionViewShowGuideLine= new TDEToggleAction( i18n( "Guide Lines" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( viewGuideLines() ),
actionCollection(), "view_guidelines" );
- actionViewShowGrid = new KToggleAction( i18n( "Show &Grid" ), 0,
+ actionViewShowGrid = new TDEToggleAction( i18n( "Show &Grid" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( viewGrid() ),
actionCollection(), "view_grid" );
actionViewShowGrid->setCheckedState(i18n("Hide &Grid"));
- actionViewSnapToGrid= new KToggleAction( i18n( "Snap to Grid" ), 0,
+ actionViewSnapToGrid= new TDEToggleAction( i18n( "Snap to Grid" ), 0,
TQT_TQOBJECT(this), TQT_SLOT(viewSnapToGrid() ),
actionCollection(), "view_snaptogrid" );
// ---------------- insert actions
- actionInsertPage = new KAction( i18n( "&Slide..." ), "slide", TQt::Key_F2,
+ actionInsertPage = new TDEAction( i18n( "&Slide..." ), "slide", TQt::Key_F2,
TQT_TQOBJECT(this), TQT_SLOT( insertPage() ),
actionCollection(), "insert_page" );
- new KAction( i18n( "Insert &Slide..." ), "newslide", 0,
+ new TDEAction( i18n( "Insert &Slide..." ), "newslide", 0,
TQT_TQOBJECT(this), TQT_SLOT( insertPage() ),
actionCollection(), "insert_page_popup" );
- actionInsertPicture = new KAction( i18n( "P&icture..." ), "frame_image", TQt::SHIFT+TQt::Key_F5,
+ actionInsertPicture = new TDEAction( i18n( "P&icture..." ), "frame_image", TQt::SHIFT+TQt::Key_F5,
TQT_TQOBJECT(this), TQT_SLOT( insertPicture() ),
actionCollection(), "insert_picture" );
// ----------------- tools actions
- actionToolsMouse = new KToggleAction( i18n( "Select" ), "select", 0,
+ actionToolsMouse = new TDEToggleAction( i18n( "Select" ), "select", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsMouse() ),
actionCollection(), "tools_mouse" );
actionToolsMouse->setExclusiveGroup( "tools" );
actionToolsMouse->setChecked( true );
- actionToolsRotate = new KToggleAction( i18n( "&Rotate" ), "rotate", 0,
+ actionToolsRotate = new TDEToggleAction( i18n( "&Rotate" ), "rotate", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsRotate() ),
actionCollection(), "tools_rotate" );
actionToolsRotate->setExclusiveGroup( "tools" );
- actionToolsZoom = new KToggleAction( i18n( "&Zoom" ), "viewmag", 0,
+ actionToolsZoom = new TDEToggleAction( i18n( "&Zoom" ), "viewmag", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsZoom() ),
actionCollection(), "tools_zoom" );
actionToolsZoom->setExclusiveGroup( "tools" );
- actionToolsShapePopup = new KActionMenu( i18n( "&Shape" ), "rectangle",
+ actionToolsShapePopup = new TDEActionMenu( i18n( "&Shape" ), "rectangle",
actionCollection(), "tools_shapepopup" );
actionToolsShapePopup->setDelayed(true);
connect(actionToolsShapePopup, TQT_SIGNAL(activated()), TQT_TQOBJECT(this), TQT_SLOT(toolsShapePopup()));
- actionToolsRectangle = new KToggleAction( i18n( "&Rectangle" ), "rectangle",
+ actionToolsRectangle = new TDEToggleAction( i18n( "&Rectangle" ), "rectangle",
0, TQT_TQOBJECT(this), TQT_SLOT( toolsRectangle() ),
actionCollection(), "tools_rectangle" );
actionToolsRectangle->setExclusiveGroup( "tools" );
- actionToolsCircleOrEllipse = new KToggleAction( i18n( "&Circle/Ellipse" ), "circle",
+ actionToolsCircleOrEllipse = new TDEToggleAction( i18n( "&Circle/Ellipse" ), "circle",
0, TQT_TQOBJECT(this), TQT_SLOT( toolsCircleOrEllipse() ),
actionCollection(), "tools_circle" );
actionToolsCircleOrEllipse->setExclusiveGroup( "tools" );
- actionToolsPie = new KToggleAction( i18n( "&Pie/Arc/Chord" ), "pie", 0,
+ actionToolsPie = new TDEToggleAction( i18n( "&Pie/Arc/Chord" ), "pie", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsPie() ),
actionCollection(), "tools_pie" );
actionToolsPie->setExclusiveGroup( "tools" );
- actionToolsText = new KToggleAction( i18n( "&Text" ), "frame_text", TQt::Key_F10, // same shortcut as KWord
+ actionToolsText = new TDEToggleAction( i18n( "&Text" ), "frame_text", TQt::Key_F10, // same shortcut as KWord
TQT_TQOBJECT(this), TQT_SLOT( toolsText() ),
actionCollection(), "tools_text" );
actionToolsText->setExclusiveGroup( "tools" );
- actionToolsAutoform = new KToggleAction( i18n( "&Arrows && Connections" ), "autoform",
+ actionToolsAutoform = new TDEToggleAction( i18n( "&Arrows && Connections" ), "autoform",
0, TQT_TQOBJECT(this), TQT_SLOT( toolsAutoform() ),
actionCollection(), "tools_autoform" );
actionToolsAutoform->setExclusiveGroup( "tools" );
- actionToolsDiagramm = new KToggleAction( i18n( "&Chart" ), "frame_chart", 0,
+ actionToolsDiagramm = new TDEToggleAction( i18n( "&Chart" ), "frame_chart", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsDiagramm() ),
actionCollection(), "tools_diagramm" );
actionToolsDiagramm->setExclusiveGroup( "tools" );
- actionToolsTable = new KToggleAction( i18n( "Ta&ble"), "frame_spreadsheet", TQt::Key_F5 /*same as kword*/,
+ actionToolsTable = new TDEToggleAction( i18n( "Ta&ble"), "frame_spreadsheet", TQt::Key_F5 /*same as kword*/,
TQT_TQOBJECT(this), TQT_SLOT( toolsTable() ),
actionCollection(), "tools_table" );
actionToolsTable->setExclusiveGroup( "tools" );
@@ -2457,137 +2457,137 @@ void KPrView::setupActions()
TQT_TQOBJECT(this), TQT_SLOT( toolsObject() ),
actionCollection(), "tools_object" );
- actionToolsLinePopup = new KActionMenu( i18n( "&Line" ), "line",
+ actionToolsLinePopup = new TDEActionMenu( i18n( "&Line" ), "line",
actionCollection(), "tools_linepopup" );
actionToolsLinePopup->setDelayed(true);
connect(actionToolsLinePopup, TQT_SIGNAL(activated()), TQT_TQOBJECT(this), TQT_SLOT(toolsLinePopup()));
- actionToolsLine = new KToggleAction( i18n( "&Line" ), "line", 0,
+ actionToolsLine = new TDEToggleAction( i18n( "&Line" ), "line", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsLine() ),
actionCollection(), "tools_line" );
actionToolsLine->setExclusiveGroup( "tools" );
- actionToolsFreehand = new KToggleAction( i18n( "&Freehand" ), "freehand", 0,
+ actionToolsFreehand = new TDEToggleAction( i18n( "&Freehand" ), "freehand", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsFreehand() ),
actionCollection(), "tools_freehand" );
actionToolsFreehand->setExclusiveGroup( "tools" );
- actionToolsPolyline = new KToggleAction( i18n( "Po&lyline" ), "polyline", 0,
+ actionToolsPolyline = new TDEToggleAction( i18n( "Po&lyline" ), "polyline", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsPolyline() ),
actionCollection(), "tools_polyline" );
actionToolsPolyline->setExclusiveGroup( "tools" );
- actionToolsQuadricBezierCurve = new KToggleAction( i18n( "&Quadric Bezier Curve" ), "quadricbeziercurve", 0,
+ actionToolsQuadricBezierCurve = new TDEToggleAction( i18n( "&Quadric Bezier Curve" ), "quadricbeziercurve", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsQuadricBezierCurve() ),
actionCollection(), "tools_quadricbeziercurve" );
actionToolsQuadricBezierCurve->setExclusiveGroup( "tools" );
- actionToolsCubicBezierCurve = new KToggleAction( i18n( "C&ubic Bezier Curve" ), "cubicbeziercurve", 0,
+ actionToolsCubicBezierCurve = new TDEToggleAction( i18n( "C&ubic Bezier Curve" ), "cubicbeziercurve", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsCubicBezierCurve() ),
actionCollection(), "tools_cubicbeziercurve" );
actionToolsCubicBezierCurve->setExclusiveGroup( "tools" );
- actionToolsConvexOrConcavePolygon = new KToggleAction( i18n( "Co&nvex/Concave Polygon" ), "polygon", 0,
+ actionToolsConvexOrConcavePolygon = new TDEToggleAction( i18n( "Co&nvex/Concave Polygon" ), "polygon", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsConvexOrConcavePolygon() ),
actionCollection(), "tools_polygon" );
actionToolsConvexOrConcavePolygon->setExclusiveGroup( "tools" );
- actionToolsClosedLinePopup = new KActionMenu( i18n( "&Closed Line" ), "closed_freehand",
+ actionToolsClosedLinePopup = new TDEActionMenu( i18n( "&Closed Line" ), "closed_freehand",
actionCollection(), "tools_closed_linepopup" );
actionToolsClosedLinePopup->setDelayed(true);
connect(actionToolsClosedLinePopup, TQT_SIGNAL(activated()), TQT_TQOBJECT(this), TQT_SLOT(toolsClosedLinePopup()));
- actionToolsClosedFreehand = new KToggleAction( i18n( "Closed &Freehand" ), "closed_freehand", 0,
+ actionToolsClosedFreehand = new TDEToggleAction( i18n( "Closed &Freehand" ), "closed_freehand", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsClosedFreehand() ),
actionCollection(), "tools_closed_freehand" );
actionToolsClosedFreehand->setExclusiveGroup( "tools" );
- actionToolsClosedPolyline = new KToggleAction( i18n( "Closed Po&lyline" ), "closed_polyline", 0,
+ actionToolsClosedPolyline = new TDEToggleAction( i18n( "Closed Po&lyline" ), "closed_polyline", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsClosedPolyline() ),
actionCollection(), "tools_closed_polyline" );
actionToolsClosedPolyline->setExclusiveGroup( "tools" );
- actionToolsClosedQuadricBezierCurve = new KToggleAction( i18n( "Closed &Quadric Bezier Curve" ), "closed_quadricbeziercurve", 0,
+ actionToolsClosedQuadricBezierCurve = new TDEToggleAction( i18n( "Closed &Quadric Bezier Curve" ), "closed_quadricbeziercurve", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsClosedQuadricBezierCurve() ),
actionCollection(), "tools_closed_quadricbeziercurve" );
actionToolsClosedQuadricBezierCurve->setExclusiveGroup( "tools" );
- actionToolsClosedCubicBezierCurve = new KToggleAction( i18n( "Closed C&ubic Bezier Curve" ), "closed_cubicbeziercurve", 0,
+ actionToolsClosedCubicBezierCurve = new TDEToggleAction( i18n( "Closed C&ubic Bezier Curve" ), "closed_cubicbeziercurve", 0,
TQT_TQOBJECT(this), TQT_SLOT( toolsClosedCubicBezierCurve() ),
actionCollection(), "tools_closed_cubicbeziercurve" );
actionToolsClosedCubicBezierCurve->setExclusiveGroup( "tools" );
// ----------------- text actions
- actionTextFont = new KAction( i18n( "&Font..." ), 0, TQT_TQOBJECT(this), TQT_SLOT( mtextFont() ),
+ actionTextFont = new TDEAction( i18n( "&Font..." ), 0, TQT_TQOBJECT(this), TQT_SLOT( mtextFont() ),
actionCollection(), "text_font" );
- actionTextFontSize = new KFontSizeAction( i18n( "Font Size" ), 0, actionCollection(), "text_fontsize" );
+ actionTextFontSize = new TDEFontSizeAction( i18n( "Font Size" ), 0, actionCollection(), "text_fontsize" );
connect( actionTextFontSize, TQT_SIGNAL( fontSizeChanged( int ) ),
TQT_TQOBJECT(this), TQT_SLOT( sizeSelected( int ) ) );
#ifdef KFONTACTION_HAS_CRITERIA_ARG
- actionTextFontFamily = new KFontAction( KFontChooser::SmoothScalableFonts,
+ actionTextFontFamily = new TDEFontAction( TDEFontChooser::SmoothScalableFonts,
i18n( "Font Family" ), 0,
actionCollection(), "text_fontfamily" );
#else
- actionTextFontFamily = new KFontAction( i18n( "Font Family" ), 0,
+ actionTextFontFamily = new TDEFontAction( i18n( "Font Family" ), 0,
actionCollection(), "text_fontfamily" );
#endif
connect( actionTextFontFamily , TQT_SIGNAL( activated( const TQString & ) ),
TQT_TQOBJECT(this), TQT_SLOT( fontSelected( const TQString & ) ) );
- actionTextBold = new KToggleAction( i18n( "&Bold" ), "text_bold", CTRL + TQt::Key_B,
+ actionTextBold = new TDEToggleAction( i18n( "&Bold" ), "text_bold", CTRL + TQt::Key_B,
TQT_TQOBJECT(this), TQT_SLOT( textBold() ),
actionCollection(), "text_bold" );
- actionTextItalic = new KToggleAction( i18n( "&Italic" ), "text_italic", CTRL + TQt::Key_I,
+ actionTextItalic = new TDEToggleAction( i18n( "&Italic" ), "text_italic", CTRL + TQt::Key_I,
TQT_TQOBJECT(this), TQT_SLOT( textItalic() ),
actionCollection(), "text_italic" );
- actionTextUnderline = new KToggleAction( i18n( "&Underline" ), "text_under", CTRL + TQt::Key_U,
+ actionTextUnderline = new TDEToggleAction( i18n( "&Underline" ), "text_under", CTRL + TQt::Key_U,
TQT_TQOBJECT(this), TQT_SLOT( textUnderline() ),
actionCollection(), "text_underline" );
- actionFormatStrikeOut = new KToggleAction( i18n( "&Strike Out" ), "text_strike", 0 ,
+ actionFormatStrikeOut = new TDEToggleAction( i18n( "&Strike Out" ), "text_strike", 0 ,
TQT_TQOBJECT(this), TQT_SLOT( textStrikeOut() ),
actionCollection(), "format_strike" );
- actionTextColor = new TKSelectColorAction( i18n( "&Color..." ), TKSelectColorAction::TextColor,
+ actionTextColor = new TTDESelectColorAction( i18n( "&Color..." ), TTDESelectColorAction::TextColor,
actionCollection(), "text_color" ,true);
connect( actionTextColor, TQT_SIGNAL( activated() ), TQT_SLOT( textColor() ) );
actionTextColor->setDefaultColor(TQColor());
- actionTextAlignLeft = new KToggleAction( i18n( "Align &Left" ), "text_left", ALT + TQt::Key_L,
+ actionTextAlignLeft = new TDEToggleAction( i18n( "Align &Left" ), "text_left", ALT + TQt::Key_L,
TQT_TQOBJECT(this), TQT_SLOT( textAlignLeft() ),
actionCollection(), "text_alignleft" );
actionTextAlignLeft->setExclusiveGroup( "align" );
actionTextAlignLeft->setChecked( true );
- actionTextAlignCenter = new KToggleAction( i18n( "Align &Center" ), "text_center", ALT + TQt::Key_C,
+ actionTextAlignCenter = new TDEToggleAction( i18n( "Align &Center" ), "text_center", ALT + TQt::Key_C,
TQT_TQOBJECT(this), TQT_SLOT( textAlignCenter() ),
actionCollection(), "text_aligncenter" );
actionTextAlignCenter->setExclusiveGroup( "align" );
- actionTextAlignRight = new KToggleAction( i18n( "Align &Right" ), "text_right", ALT + TQt::Key_R,
+ actionTextAlignRight = new TDEToggleAction( i18n( "Align &Right" ), "text_right", ALT + TQt::Key_R,
TQT_TQOBJECT(this), TQT_SLOT( textAlignRight() ),
actionCollection(), "text_alignright" );
actionTextAlignRight->setExclusiveGroup( "align" );
- actionTextAlignBlock = new KToggleAction( i18n( "Align &Block" ), "text_block", CTRL + TQt::Key_J,
+ actionTextAlignBlock = new TDEToggleAction( i18n( "Align &Block" ), "text_block", CTRL + TQt::Key_J,
TQT_TQOBJECT(this), TQT_SLOT( textAlignBlock() ),
actionCollection(), "text_alignblock" );
actionTextAlignBlock->setExclusiveGroup( "align" );
- actionFormatNumber = new KActionMenu( i18n( "Number" ), "enumList", actionCollection(), "format_number" );
+ actionFormatNumber = new TDEActionMenu( i18n( "Number" ), "enumList", actionCollection(), "format_number" );
actionFormatNumber->setDelayed( false );
- actionFormatBullet = new KActionMenu( i18n( "Bullet" ), "unsortedList", actionCollection(), "format_bullet" );
+ actionFormatBullet = new TDEActionMenu( i18n( "Bullet" ), "unsortedList", actionCollection(), "format_bullet" );
actionFormatBullet->setDelayed( false );
TQPtrList<KoCounterStyleWidget::StyleRepresenter> stylesList;
KoCounterStyleWidget::makeCounterRepresenterList( stylesList );
@@ -2595,7 +2595,7 @@ void KPrView::setupActions()
for ( ; styleIt.current() ; ++styleIt ) {
// Dynamically create toggle-actions for each list style.
// This approach allows to edit toolbars and extract separate actions from this menu
- KToggleAction* act = new KToggleAction( styleIt.current()->name(), /*TODO icon,*/
+ TDEToggleAction* act = new TDEToggleAction( styleIt.current()->name(), /*TODO icon,*/
0, TQT_TQOBJECT(this), TQT_SLOT( slotCounterStyleSelected() ),
actionCollection(), TQString("counterstyle_%1").arg( styleIt.current()->style() ).latin1() );
act->setExclusiveGroup( "counterstyle" );
@@ -2608,140 +2608,140 @@ void KPrView::setupActions()
else
actionFormatNumber->insert( act );
}
- actionTextDepthPlus = new KAction( i18n( "&Increase Depth" ), TQApplication::reverseLayout() ?"format_decreaseindent" : "format_increaseindent",
+ actionTextDepthPlus = new TDEAction( i18n( "&Increase Depth" ), TQApplication::reverseLayout() ?"format_decreaseindent" : "format_increaseindent",
CTRL + TQt::Key_Plus, TQT_TQOBJECT(this), TQT_SLOT( textDepthPlus() ),
actionCollection(), "text_depthPlus" );
- actionTextDepthMinus = new KAction( i18n( "&Decrease Depth" ), TQApplication::reverseLayout() ?"format_increaseindent" : "format_decreaseindent",
+ actionTextDepthMinus = new TDEAction( i18n( "&Decrease Depth" ), TQApplication::reverseLayout() ?"format_increaseindent" : "format_decreaseindent",
CTRL + TQt::Key_Minus, TQT_TQOBJECT(this), TQT_SLOT( textDepthMinus() ),
actionCollection(), "text_depthMinus" );
- actionTextExtentCont2Height = new KAction( i18n( "Extend Contents to Object &Height" ), 0,
+ actionTextExtentCont2Height = new TDEAction( i18n( "Extend Contents to Object &Height" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( textContentsToHeight() ),
actionCollection(), "text_con2hei" );
- actionTextExtendObj2Cont = new KAction( i18n( "&Extend Object to Fit Contents" ), 0,
+ actionTextExtendObj2Cont = new TDEAction( i18n( "&Extend Object to Fit Contents" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( textObjectToContents() ),
actionCollection(), "text_obj2cont" );
- actionTextInsertPageNum = new KAction( i18n( "&Insert Slide Number" ), "pgnum", 0,
+ actionTextInsertPageNum = new TDEAction( i18n( "&Insert Slide Number" ), "pgnum", 0,
TQT_TQOBJECT(this), TQT_SLOT( textInsertPageNum() ),
actionCollection(), "text_inspgnum" );
// ----------------- format actions
- actionExtraProperties = new KAction( i18n( "&Properties" ), "penbrush", 0,
+ actionExtraProperties = new TDEAction( i18n( "&Properties" ), "penbrush", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraProperties() ),
actionCollection(), "extra_properties" );
- actionExtraArrangePopup = new KActionMenu( i18n( "Arra&nge Objects" ), "arrange",
+ actionExtraArrangePopup = new TDEActionMenu( i18n( "Arra&nge Objects" ), "arrange",
actionCollection(), "extra_arrangepopup" );
actionExtraArrangePopup->setDelayed( false );
- actionExtraRaise = new KAction( i18n( "Ra&ise Objects" ), "raise",
+ actionExtraRaise = new TDEAction( i18n( "Ra&ise Objects" ), "raise",
CTRL+TQt::SHIFT+TQt::Key_R, TQT_TQOBJECT(this), TQT_SLOT( extraRaise() ),
actionCollection(), "extra_raise" );
- actionExtraLower = new KAction( i18n( "&Lower Objects" ), "lower", CTRL +TQt::SHIFT+ TQt::Key_L,
+ actionExtraLower = new TDEAction( i18n( "&Lower Objects" ), "lower", CTRL +TQt::SHIFT+ TQt::Key_L,
TQT_TQOBJECT(this), TQT_SLOT( extraLower() ),
actionCollection(), "extra_lower" );
- actionExtraBringForward= new KAction( i18n( "Bring to Front" ), "bring_forward",
+ actionExtraBringForward= new TDEAction( i18n( "Bring to Front" ), "bring_forward",
0, TQT_TQOBJECT(this), TQT_SLOT( extraBringForward() ),
actionCollection(), "extra_bring_forward" );
- actionExtraSendBackward= new KAction( i18n( "Send to Back" ), "send_backward",
+ actionExtraSendBackward= new TDEAction( i18n( "Send to Back" ), "send_backward",
0, TQT_TQOBJECT(this), TQT_SLOT( extraSendBackward() ),
actionCollection(), "extra_send_backward" );
- actionExtraRotate = new KAction( i18n( "R&otate Objects..." ), "rotate_cw", 0,
+ actionExtraRotate = new TDEAction( i18n( "R&otate Objects..." ), "rotate_cw", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraRotate() ),
actionCollection(), "extra_rotate" );
- actionExtraShadow = new KAction( i18n( "&Shadow Objects..." ), "shadow", 0,
+ actionExtraShadow = new TDEAction( i18n( "&Shadow Objects..." ), "shadow", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraShadow() ),
actionCollection(), "extra_shadow" );
- actionExtraAlignObjLeft = new KAction( i18n( "Align &Left" ), "aoleft", 0,
+ actionExtraAlignObjLeft = new TDEAction( i18n( "Align &Left" ), "aoleft", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraAlignObjLeft() ),
actionCollection(), "extra_alignleft" );
- actionExtraAlignObjCenterH = new KAction( i18n( "Align Center (&horizontally)" ),
+ actionExtraAlignObjCenterH = new TDEAction( i18n( "Align Center (&horizontally)" ),
"aocenterh", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraAlignObjCenterH() ),
actionCollection(), "extra_aligncenterh" );
- actionExtraAlignObjRight = new KAction( i18n( "Align &Right" ), "aoright", 0,
+ actionExtraAlignObjRight = new TDEAction( i18n( "Align &Right" ), "aoright", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraAlignObjRight() ),
actionCollection(), "extra_alignright" );
- actionExtraAlignObjTop = new KAction( i18n( "Align &Top" ), "aotop", 0,
+ actionExtraAlignObjTop = new TDEAction( i18n( "Align &Top" ), "aotop", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraAlignObjTop() ),
actionCollection(), "extra_aligntop" );
- actionExtraAlignObjCenterV = new KAction( i18n( "Align Center (&vertically)" ),
+ actionExtraAlignObjCenterV = new TDEAction( i18n( "Align Center (&vertically)" ),
"aocenterv", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraAlignObjCenterV() ),
actionCollection(), "extra_aligncenterv" );
- actionExtraAlignObjBottom = new KAction( i18n( "Align &Bottom" ), "aobottom", 0,
+ actionExtraAlignObjBottom = new TDEAction( i18n( "Align &Bottom" ), "aobottom", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraAlignObjBottom() ),
actionCollection(), "extra_alignbottom" );
- actionExtraBackground = new KAction( i18n( "Slide Bac&kground..." ), "background", 0,
+ actionExtraBackground = new TDEAction( i18n( "Slide Bac&kground..." ), "background", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraBackground() ),
actionCollection(), "extra_background" );
- actionExtraLayout = new KAction( i18n( "Page &Layout..." ), 0,
+ actionExtraLayout = new TDEAction( i18n( "Page &Layout..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( extraLayout() ),
actionCollection(), "extra_layout" );
- m_actionExtraHeader = new KToggleAction( i18n( "Enable Document &Header" ), 0,
+ m_actionExtraHeader = new TDEToggleAction( i18n( "Enable Document &Header" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( viewHeader() ),
actionCollection(), "extra_header" );
m_actionExtraHeader->setCheckedState( i18n( "Disable Document &Header" ) );
m_actionExtraHeader->setToolTip( i18n( "Shows and hides header display for the current slide." ) );
- m_actionExtraFooter = new KToggleAction( i18n( "Enable Document Foo&ter" ), 0,
+ m_actionExtraFooter = new TDEToggleAction( i18n( "Enable Document Foo&ter" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( viewFooter() ),
actionCollection(), "extra_footer" );
m_actionExtraFooter->setCheckedState( i18n( "Disable Document Foo&ter" ) );
m_actionExtraFooter->setToolTip( i18n( "Shows and hides footer display for the current slide." ) );
- actionExtraConfigure = new KAction( i18n( "Configure KPresenter..." ),
+ actionExtraConfigure = new TDEAction( i18n( "Configure KPresenter..." ),
"configure", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraConfigure() ),
actionCollection(), "extra_configure" );
- actionExtraWebPres = new KAction( i18n( "Create &HTML Slideshow..." ),
+ actionExtraWebPres = new TDEAction( i18n( "Create &HTML Slideshow..." ),
"webpres", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraWebPres() ),
actionCollection(), "extra_webpres" );
- actionExtraMSPres = new KAction( i18n( "Create Memor&y Stick Slideshow..." ),
+ actionExtraMSPres = new TDEAction( i18n( "Create Memor&y Stick Slideshow..." ),
0, TQT_TQOBJECT(this), TQT_SLOT( extraMSPres() ),
actionCollection(), "extra_mspres" );
- actionExtraCreateTemplate = new KAction( i18n( "Template Manager" ), 0,
+ actionExtraCreateTemplate = new TDEAction( i18n( "Template Manager" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( extraCreateTemplate() ),
actionCollection(), "extra_template" );
- actionExtraDefaultTemplate = new KAction( i18n( "Use Current Slide as Default Template" ), 0,
+ actionExtraDefaultTemplate = new TDEAction( i18n( "Use Current Slide as Default Template" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( extraDefaultTemplate() ),
actionCollection(), "extra_defaulttemplate" );
- actionExtraAlignObjsPopup = new KActionMenu( i18n("Align O&bjects"), "alignobjs",
+ actionExtraAlignObjsPopup = new TDEActionMenu( i18n("Align O&bjects"), "alignobjs",
actionCollection(), "extra_alignobjs" );
actionExtraAlignObjsPopup->setDelayed( false );
- actionExtraLineBegin = new KAction( i18n("Line Begin"), "line_begin", 0,
+ actionExtraLineBegin = new TDEAction( i18n("Line Begin"), "line_begin", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraLineBegin() ),
actionCollection(), "extra_linebegin" );
- actionExtraLineEnd = new KAction( i18n("Line End"), "line_end", 0,
+ actionExtraLineEnd = new TDEAction( i18n("Line End"), "line_end", 0,
TQT_TQOBJECT(this), TQT_SLOT( extraLineEnd() ),
actionCollection(), "extra_lineend" );
@@ -2758,138 +2758,138 @@ void KPrView::setupActions()
connect( kPresenterDoc(), TQT_SIGNAL( unitChanged( KoUnit::Unit ) ),
actionExtraPenWidth, TQT_SLOT( setUnit( KoUnit::Unit ) ) );
- actionExtraGroup = new KAction( i18n( "&Group Objects" ), "group",
+ actionExtraGroup = new TDEAction( i18n( "&Group Objects" ), "group",
TQKeySequence( "Ctrl+G" ),
TQT_TQOBJECT(this), TQT_SLOT( extraGroup() ),
actionCollection(), "extra_group" );
- actionExtraUnGroup = new KAction( i18n( "&Ungroup Objects" ), "ungroup",
+ actionExtraUnGroup = new TDEAction( i18n( "&Ungroup Objects" ), "ungroup",
TQKeySequence( "Ctrl+Shift+G" ),
TQT_TQOBJECT(this), TQT_SLOT( extraUnGroup() ),
actionCollection(), "extra_ungroup" );
// ----------------- slideshow actions
- actionScreenConfigPages = new KAction( i18n( "&Configure Slide Show..." ),
+ actionScreenConfigPages = new TDEAction( i18n( "&Configure Slide Show..." ),
"configure", 0,
TQT_TQOBJECT(this), TQT_SLOT( screenConfigPages() ),
actionCollection(), "screen_configpages" );
- actionScreenAssignEffect = new KAction( i18n( "Edit &Object Effect..." ),
+ actionScreenAssignEffect = new TDEAction( i18n( "Edit &Object Effect..." ),
"effect", 0,
TQT_TQOBJECT(this), TQT_SLOT( screenAssignEffect() ),
actionCollection(), "screen_assigneffect");
- actionScreenTransEffect = new KAction( i18n( "Edit Slide &Transition..." ),
+ actionScreenTransEffect = new TDEAction( i18n( "Edit Slide &Transition..." ),
"slide_effect", 0,
TQT_TQOBJECT(this), TQT_SLOT( screenTransEffect() ),
actionCollection(), "screen_transeffect");
- actionScreenStart = new KAction( i18n( "&Start" ),
+ actionScreenStart = new TDEAction( i18n( "&Start" ),
"2rightarrow", TQt::Key_F12,
TQT_TQOBJECT(this), TQT_SLOT( screenStart() ),
actionCollection(), "screen_start" );
- actionScreenStartFromFirst = new KAction( i18n( "Start From &First Slide" ),
+ actionScreenStartFromFirst = new TDEAction( i18n( "Start From &First Slide" ),
"1rightarrow", 0,
TQT_TQOBJECT(this), TQT_SLOT( screenStartFromFirst() ),
actionCollection(), "screen_startfromfirst" );
- actionScreenFirst = new KAction( i18n( "&Go to Start" ),
+ actionScreenFirst = new TDEAction( i18n( "&Go to Start" ),
"start", 0,
TQT_TQOBJECT(this), TQT_SLOT( screenFirst() ),
actionCollection(), "screen_first" );
- actionScreenPrev = new KAction( i18n( "&Previous Slide" ),
+ actionScreenPrev = new TDEAction( i18n( "&Previous Slide" ),
"back", TQt::Key_Prior,
TQT_TQOBJECT(this), TQT_SLOT( screenPrev() ),
actionCollection(), "screen_prev" );
- actionScreenNext = new KAction( i18n( "&Next Slide" ),
+ actionScreenNext = new TDEAction( i18n( "&Next Slide" ),
"forward", TQt::Key_Next,
TQT_TQOBJECT(this), TQT_SLOT( screenNext() ),
actionCollection(), "screen_next" );
- actionScreenLast = new KAction( i18n( "Go to &End" ),
+ actionScreenLast = new TDEAction( i18n( "Go to &End" ),
"finish", 0,
TQT_TQOBJECT(this), TQT_SLOT( screenLast() ),
actionCollection(), "screen_last" );
- actionScreenSkip = new KAction( i18n( "Goto &Slide..." ),
+ actionScreenSkip = new TDEAction( i18n( "Goto &Slide..." ),
"goto", 0,
TQT_TQOBJECT(this), TQT_SLOT( screenSkip() ),
actionCollection(), "screen_skip" );
// ----------------- colorbar(Brush and Pen) action
- actionBrushColor = new TKSelectColorAction( i18n( "Fill Color..." ), TKSelectColorAction::FillColor,
+ actionBrushColor = new TTDESelectColorAction( i18n( "Fill Color..." ), TTDESelectColorAction::FillColor,
actionCollection(), "brush_color" ,true);
connect( actionBrushColor, TQT_SIGNAL( activated() ), TQT_SLOT( brushChosen() ) );
actionBrushColor->setDefaultColor(TQColor());
- actionPenColor = new TKSelectColorAction( i18n( "Outline Color..." ), TKSelectColorAction::LineColor,
+ actionPenColor = new TTDESelectColorAction( i18n( "Outline Color..." ), TTDESelectColorAction::LineColor,
actionCollection(), "pen_color" );
connect( actionPenColor, TQT_SIGNAL( activated() ), TQT_SLOT( penChosen() ) );
actionPenColor->setDefaultColor(TQColor());
- actionExtendObjectHeight = new KAction( i18n( "&Extend Contents to Object Height" ),0, TQT_TQOBJECT(this), TQT_SLOT( textContentsToHeight() ),
+ actionExtendObjectHeight = new TDEAction( i18n( "&Extend Contents to Object Height" ),0, TQT_TQOBJECT(this), TQT_SLOT( textContentsToHeight() ),
actionCollection(), "extendobjectheight" );
- actionResizeTextObject = new KAction( i18n( "&Resize Object to Fit Contents" ),0, TQT_TQOBJECT(this), TQT_SLOT( textObjectToContents() ),
+ actionResizeTextObject = new TDEAction( i18n( "&Resize Object to Fit Contents" ),0, TQT_TQOBJECT(this), TQT_SLOT( textObjectToContents() ),
actionCollection(), "resizetextobject" );
- actionRenamePage=new KAction(i18n( "&Rename Slide..." ),0,TQT_TQOBJECT(this),
+ actionRenamePage=new TDEAction(i18n( "&Rename Slide..." ),0,TQT_TQOBJECT(this),
TQT_SLOT( renamePageTitle() ),
actionCollection(), "rename_page" );
- actionPicOriginalSize = new KAction( i18n( "Sca&le to Original Size" ), 0, TQT_TQOBJECT(this),
+ actionPicOriginalSize = new TDEAction( i18n( "Sca&le to Original Size" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( picViewOriginalSize() ),
actionCollection(), "pic_original_size" );
- actionPic640x480=new KAction(i18n( "640x480" ),0,TQT_TQOBJECT(this),
+ actionPic640x480=new TDEAction(i18n( "640x480" ),0,TQT_TQOBJECT(this),
TQT_SLOT( picViewOrig640x480() ),
actionCollection(), "pic_640_480" );
- actionPic800x600=new KAction(i18n( "800x600" ),0,TQT_TQOBJECT(this),
+ actionPic800x600=new TDEAction(i18n( "800x600" ),0,TQT_TQOBJECT(this),
TQT_SLOT( picViewOrig800x600() ),
actionCollection(), "pic_800_600" );
- actionPic1024x768=new KAction(i18n( "1024x768" ),0,TQT_TQOBJECT(this),
+ actionPic1024x768=new TDEAction(i18n( "1024x768" ),0,TQT_TQOBJECT(this),
TQT_SLOT( picViewOrig1024x768() ),
actionCollection(), "pic_1024_768" );
- actionPic1280x1024=new KAction(i18n( "1280x1024" ),0,TQT_TQOBJECT(this),
+ actionPic1280x1024=new TDEAction(i18n( "1280x1024" ),0,TQT_TQOBJECT(this),
TQT_SLOT( picViewOrig1280x1024() ),
actionCollection(), "pic_1280_1024" );
- actionPic1600x1200=new KAction(i18n( "1600x1200" ),0,TQT_TQOBJECT(this),
+ actionPic1600x1200=new TDEAction(i18n( "1600x1200" ),0,TQT_TQOBJECT(this),
TQT_SLOT( picViewOrig1600x1200() ),
actionCollection(), "pic_1600_1200" );
- actionChangePic=new KAction( i18n( "&Change Picture..." ),"frame_image",0,TQT_TQOBJECT(this),
+ actionChangePic=new TDEAction( i18n( "&Change Picture..." ),"frame_image",0,TQT_TQOBJECT(this),
TQT_SLOT( chPic() ), actionCollection(), "change_picture" );
- actionImageEffect = new KAction( i18n("Image &Effect..."), 0, TQT_TQOBJECT(this),
+ actionImageEffect = new TDEAction( i18n("Image &Effect..."), 0, TQT_TQOBJECT(this),
TQT_SLOT(imageEffect()), actionCollection(), "image_effect");
- actionFormatSuper = new KToggleAction( i18n( "Superscript" ), "super", 0,
+ actionFormatSuper = new TDEToggleAction( i18n( "Superscript" ), "super", 0,
TQT_TQOBJECT(this), TQT_SLOT( textSuperScript() ),
actionCollection(), "format_super" );
actionFormatSuper->setExclusiveGroup( "valign" );
- actionFormatSub = new KToggleAction( i18n( "Subscript" ), "sub", 0,
+ actionFormatSub = new TDEToggleAction( i18n( "Subscript" ), "sub", 0,
TQT_TQOBJECT(this), TQT_SLOT( textSubScript() ),
actionCollection(), "format_sub" );
actionFormatSub->setExclusiveGroup( "valign" );
- actionInsertSpecialChar = new KAction( i18n( "Sp&ecial Character..." ), "char",
+ actionInsertSpecialChar = new TDEAction( i18n( "Sp&ecial Character..." ), "char",
ALT + TQt::SHIFT + TQt::Key_C,
TQT_TQOBJECT(this), TQT_SLOT( insertSpecialChar() ),
actionCollection(), "insert_specialchar" );
- actionInsertLink = new KAction( i18n( "Link..." ), 0,
+ actionInsertLink = new TDEAction( i18n( "Link..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( insertLink() ),
actionCollection(), "insert_link" );
@@ -2899,58 +2899,58 @@ void KPrView::setupActions()
picResizeMenu->insertSeparator();
picResizeMenu->insertItem( i18n( "Enter Custom Factor..." ), TQT_TQOBJECT(this), TQT_SLOT( picViewOrigFactor() ) );
#endif
- (void) new KAction( i18n( "Configure &Autocorrection..." ), 0,
+ (void) new TDEAction( i18n( "Configure &Autocorrection..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( extraAutoFormat() ),
actionCollection(), "extra_autocorrection" );
actionExtraSpellCheck = KStdAction::spelling( TQT_TQOBJECT(this), TQT_SLOT( slotSpellCheck() ), actionCollection(), "extra_spellcheck" );
- actionFormatParag = new KAction( i18n( "&Paragraph..." ), ALT + CTRL + TQt::Key_P,
+ actionFormatParag = new TDEAction( i18n( "&Paragraph..." ), ALT + CTRL + TQt::Key_P,
TQT_TQOBJECT(this), TQT_SLOT( formatParagraph() ),
actionCollection(), "format_paragraph" );
- actionFormatDefault=new KAction( i18n( "Default Format" ), 0,
+ actionFormatDefault=new TDEAction( i18n( "Default Format" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( textDefaultFormat() ),
actionCollection(), "text_default" );
- actionOpenLink = new KAction( i18n( "Open Link" ), 0,
+ actionOpenLink = new TDEAction( i18n( "Open Link" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( openLink() ),
actionCollection(), "open_link" );
- actionChangeLink=new KAction( i18n("Change Link..."), 0,
+ actionChangeLink=new TDEAction( i18n("Change Link..."), 0,
TQT_TQOBJECT(this), TQT_SLOT(changeLink()),
actionCollection(), "change_link");
- actionCopyLink = new KAction( i18n( "Copy Link" ), 0,
+ actionCopyLink = new TDEAction( i18n( "Copy Link" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( copyLink() ),
actionCollection(), "copy_link" );
- actionRemoveLink = new KAction( i18n( "Remove Link" ), 0,
+ actionRemoveLink = new TDEAction( i18n( "Remove Link" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( removeLink() ),
actionCollection(), "remove_link" );
- actionAddLinkToBookmak = new KAction( i18n( "Add to Bookmark" ), 0,
+ actionAddLinkToBookmak = new TDEAction( i18n( "Add to Bookmark" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( addToBookmark() ),
actionCollection(), "add_to_bookmark" );
- actionEditCustomVarsEdit = new KAction( i18n( "&Custom Variables..." ), 0,
+ actionEditCustomVarsEdit = new TDEAction( i18n( "&Custom Variables..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( editCustomVars() ),
actionCollection(), "edit_vars" );
- actionEditCustomVars = new KAction( i18n( "Edit Variable..." ), 0,
+ actionEditCustomVars = new TDEAction( i18n( "Edit Variable..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( editCustomVariable() ),
actionCollection(), "edit_customvars" );
m_variableDefMap.clear();
- actionInsertVariable = new KActionMenu( i18n( "&Variable" ),
+ actionInsertVariable = new TDEActionMenu( i18n( "&Variable" ),
actionCollection(), "insert_variable" );
// The last argument is only needed if a submenu is to be created
addVariableActions( VT_FIELD, KoFieldVariable::actionTexts(), actionInsertVariable, i18n("&Property") );
addVariableActions( VT_DATE, KoDateVariable::actionTexts(), actionInsertVariable, i18n("&Date") );
addVariableActions( VT_TIME, KoTimeVariable::actionTexts(), actionInsertVariable, i18n("&Time") );
- actionInsertCustom = new KActionMenu( i18n( "&Custom" ),
+ actionInsertCustom = new TDEActionMenu( i18n( "&Custom" ),
actionCollection(), "insert_custom" );
actionInsertVariable->insert(actionInsertCustom);
refreshCustomMenu();
@@ -2959,200 +2959,200 @@ void KPrView::setupActions()
addVariableActions( VT_STATISTIC, KPrStatisticVariable::actionTexts(), actionInsertVariable, i18n("&Statistic") );
actionInsertVariable->popupMenu()->insertSeparator();
- actionRefreshAllVariable = new KAction( i18n( "&Refresh All Variables" ), 0,
+ actionRefreshAllVariable = new TDEAction( i18n( "&Refresh All Variables" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( refreshAllVariable() ),
actionCollection(), "refresh_all_variable" );
actionInsertVariable->insert(actionRefreshAllVariable);
- actionIncreaseFontSize = new KAction( i18n("Increase Font Size"),"fontsizeup", 0,
+ actionIncreaseFontSize = new TDEAction( i18n("Increase Font Size"),"fontsizeup", 0,
TQT_TQOBJECT(this), TQT_SLOT( increaseFontSize() ),
actionCollection(), "increaseFontSize" );
- actionDecreaseFontSize = new KAction( i18n("Decrease Font Size"),"fontsizedown", 0,
+ actionDecreaseFontSize = new TDEAction( i18n("Decrease Font Size"),"fontsizedown", 0,
TQT_TQOBJECT(this), TQT_SLOT( decreaseFontSize() ),
actionCollection(), "decreaseFontSize" );
- actionChangeCase=new KAction( i18n( "Change Case..." ), 0,
+ actionChangeCase=new TDEAction( i18n( "Change Case..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( changeCaseOfText() ),
actionCollection(), "change_case" );
- actionViewZoom = new KSelectAction( i18n( "Zoom" ), "viewmag", 0,
+ actionViewZoom = new TDESelectAction( i18n( "Zoom" ), "viewmag", 0,
actionCollection(), "view_zoom" );
connect( actionViewZoom, TQT_SIGNAL( activated( const TQString & ) ),
TQT_TQOBJECT(this), TQT_SLOT( viewZoom( const TQString & ) ) );
actionViewZoom->setEditable(true);
changeZoomMenu( );
- actionFormatStylist = new KAction( i18n( "&Style Manager" ), ALT + CTRL + TQt::Key_S,
+ actionFormatStylist = new TDEAction( i18n( "&Style Manager" ), ALT + CTRL + TQt::Key_S,
TQT_TQOBJECT(this), TQT_SLOT( extraStylist() ),
actionCollection(), "format_stylist" );
- actionFormatStyleMenu = new KActionMenu( i18n( "St&yle" ), 0,
+ actionFormatStyleMenu = new TDEActionMenu( i18n( "St&yle" ), 0,
actionCollection(), "format_stylemenu" );
- actionFormatStyle = new KSelectAction( i18n( "St&yle" ), 0,
+ actionFormatStyle = new TDESelectAction( i18n( "St&yle" ), 0,
actionCollection(), "format_style" );
connect( actionFormatStyle, TQT_SIGNAL( activated( int ) ),
TQT_TQOBJECT(this), TQT_SLOT( textStyleSelected( int ) ) );
actionFormatStyle->setMenuAccelsEnabled( true );
updateStyleList();
- actionAllowAutoFormat = new KToggleAction( i18n( "Enable Autocorrection" ), 0,
+ actionAllowAutoFormat = new TDEToggleAction( i18n( "Enable Autocorrection" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotAllowAutoFormat() ),
actionCollection(), "enable_autocorrection" );
actionAllowAutoFormat->setCheckedState(i18n("Disable Autocorrection"));
// ------------------- Actions with a key binding and no GUI item
- new KAction( i18n( "Insert Non-Breaking Space" ), CTRL+TQt::Key_Space,
+ new TDEAction( i18n( "Insert Non-Breaking Space" ), CTRL+TQt::Key_Space,
TQT_TQOBJECT(this), TQT_SLOT( slotNonbreakingSpace() ), actionCollection(), "nonbreaking_space" );
- new KAction( i18n( "Insert Non-Breaking Hyphen" ), CTRL+TQt::SHIFT+TQt::Key_Minus,
+ new TDEAction( i18n( "Insert Non-Breaking Hyphen" ), CTRL+TQt::SHIFT+TQt::Key_Minus,
TQT_TQOBJECT(this), TQT_SLOT( slotNonbreakingHyphen() ), actionCollection(), "nonbreaking_hyphen" );
- new KAction( i18n( "Insert Soft Hyphen" ), CTRL+TQt::Key_Minus,
+ new TDEAction( i18n( "Insert Soft Hyphen" ), CTRL+TQt::Key_Minus,
TQT_TQOBJECT(this), TQT_SLOT( slotSoftHyphen() ), actionCollection(), "soft_hyphen" );
- new KAction( i18n( "Line Break" ), TQt::SHIFT+TQt::Key_Return,
+ new TDEAction( i18n( "Line Break" ), TQt::SHIFT+TQt::Key_Return,
TQT_TQOBJECT(this), TQT_SLOT( slotLineBreak() ), actionCollection(), "line_break" );
- new KAction( i18n( "Completion" ), KStdAccel::shortcut(KStdAccel::TextCompletion),
+ new TDEAction( i18n( "Completion" ), TDEStdAccel::shortcut(TDEStdAccel::TextCompletion),
TQT_TQOBJECT(this), TQT_SLOT( slotCompletion() ), actionCollection(), "completion" );
- new KAction( i18n( "Increase Numbering Level" ), ALT+TQt::Key_Right,
+ new TDEAction( i18n( "Increase Numbering Level" ), ALT+TQt::Key_Right,
TQT_TQOBJECT(this), TQT_SLOT( slotIncreaseNumberingLevel() ), actionCollection(), "increase_numbering_level" );
- new KAction( i18n( "Decrease Numbering Level" ), ALT+TQt::Key_Left,
+ new TDEAction( i18n( "Decrease Numbering Level" ), ALT+TQt::Key_Left,
TQT_TQOBJECT(this), TQT_SLOT( slotDecreaseNumberingLevel() ), actionCollection(), "decrease_numbering_level" );
- actionInsertComment = new KAction( i18n( "Comment..." ), 0,
+ actionInsertComment = new TDEAction( i18n( "Comment..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( insertComment() ),
actionCollection(), "insert_comment" );
- actionEditComment = new KAction( i18n("Edit Comment..."), 0,
+ actionEditComment = new TDEAction( i18n("Edit Comment..."), 0,
TQT_TQOBJECT(this), TQT_SLOT(editComment()),
actionCollection(), "edit_comment");
- actionAddGuideLine = new KAction( i18n( "Add Guide Line..."), 0,
+ actionAddGuideLine = new TDEAction( i18n( "Add Guide Line..."), 0,
TQT_TQOBJECT(this), TQT_SLOT( addGuideLine()),
actionCollection(), "add_guideline");
- actionRemoveComment = new KAction( i18n("Remove Comment"), 0,
+ actionRemoveComment = new TDEAction( i18n("Remove Comment"), 0,
TQT_TQOBJECT(this), TQT_SLOT(removeComment()),
actionCollection(), "remove_comment");
- actionCopyTextOfComment = new KAction( i18n("Copy Text of Comment..."), 0,
+ actionCopyTextOfComment = new TDEAction( i18n("Copy Text of Comment..."), 0,
TQT_TQOBJECT(this), TQT_SLOT(copyTextOfComment()),
actionCollection(), "copy_text_comment");
- actionConfigureCompletion = new KAction( i18n( "&Configure Completion..." ), 0,
+ actionConfigureCompletion = new TDEAction( i18n( "&Configure Completion..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( configureCompletion() ),
actionCollection(), "configure_completion" );
- actionZoomMinus = new KAction( i18n( "Zoom Out" ), "viewmag-",0,
+ actionZoomMinus = new TDEAction( i18n( "Zoom Out" ), "viewmag-",0,
TQT_TQOBJECT(this), TQT_SLOT( zoomMinus() ),
actionCollection(), "zoom_minus" );
- actionZoomPlus = new KAction( i18n( "Zoom In" ), "viewmag+",0,
+ actionZoomPlus = new TDEAction( i18n( "Zoom In" ), "viewmag+",0,
TQT_TQOBJECT(this), TQT_SLOT( zoomPlus() ),
actionCollection(), "zoom_plus" );
- actionZoomEntirePage = new KAction( i18n( "Zoom Entire Slide" ), 0,
+ actionZoomEntirePage = new TDEAction( i18n( "Zoom Entire Slide" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( zoomEntirePage() ),
actionCollection(), "zoom_entire_page" );
- actionZoomMinus = new KAction( i18n( "Zoom Slide Width" ), 0,
+ actionZoomMinus = new TDEAction( i18n( "Zoom Slide Width" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( zoomPageWidth() ),
actionCollection(), "zoom_page_width" );
- actionZoomSelectedObject= new KAction( i18n( "Zoom Selected Objects" ), "viewmagfit",0,
+ actionZoomSelectedObject= new TDEAction( i18n( "Zoom Selected Objects" ), "viewmagfit",0,
TQT_TQOBJECT(this), TQT_SLOT( zoomSelectedObject() ),
actionCollection(), "zoom_selected_object" );
- actionZoomPageHeight= new KAction( i18n( "Zoom Slide Height" ), 0,
+ actionZoomPageHeight= new TDEAction( i18n( "Zoom Slide Height" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( zoomPageHeight() ),
actionCollection(), "zoom_page_height" );
- actionZoomAllObject= new KAction( i18n( "Zoom All Objects" ), 0,
+ actionZoomAllObject= new TDEAction( i18n( "Zoom All Objects" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( zoomAllObject() ),
actionCollection(), "zoom_all_object" );
- actionFlipHorizontal= new KAction( i18n( "Horizontal Flip" ), 0,
+ actionFlipHorizontal= new TDEAction( i18n( "Horizontal Flip" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( flipHorizontal() ),
actionCollection(), "horizontal_flip" );
- actionFlipVertical= new KAction( i18n( "Vertical Flip" ), 0,
+ actionFlipVertical= new TDEAction( i18n( "Vertical Flip" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( flipVertical() ),
actionCollection(), "vertical_flip" );
- actionDuplicateObj = new KAction( i18n( "Duplicate Object..." ), 0,
+ actionDuplicateObj = new TDEAction( i18n( "Duplicate Object..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( duplicateObj() ),
actionCollection(), "duplicate_obj" );
- actionApplyAutoFormat= new KAction( i18n( "Apply Autocorrection" ), 0,
+ actionApplyAutoFormat= new TDEAction( i18n( "Apply Autocorrection" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( applyAutoFormat() ),
actionCollection(), "apply_autoformat" );
- actionCreateStyleFromSelection = new KAction( i18n( "Create Style From Selection..." ), 0,
+ actionCreateStyleFromSelection = new TDEAction( i18n( "Create Style From Selection..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( createStyleFromSelection()),
actionCollection(), "create_style" );
- actionCloseObject = new KAction( i18n( "Close Object" ), 0,
+ actionCloseObject = new TDEAction( i18n( "Close Object" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( closeObject()),
actionCollection(), "close_object" );
- actionAlignVerticalTop = new KToggleAction( i18n( "Align Top" ), 0,
+ actionAlignVerticalTop = new TDEToggleAction( i18n( "Align Top" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( alignVerticalTop() ),
actionCollection(), "align_top" );
actionAlignVerticalTop->setExclusiveGroup( "vertical_alignment" );
actionAlignVerticalTop->setChecked( true );
- actionAlignVerticalBottom = new KToggleAction( i18n( "Align Bottom" ), 0,
+ actionAlignVerticalBottom = new TDEToggleAction( i18n( "Align Bottom" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( alignVerticalBottom() ),
actionCollection(), "align_bottom" );
actionAlignVerticalBottom->setExclusiveGroup( "vertical_alignment" );
- actionAlignVerticalCenter = new KToggleAction( i18n( "Align Middle" ), 0,
+ actionAlignVerticalCenter = new TDEToggleAction( i18n( "Align Middle" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( alignVerticalCenter() ),
actionCollection(), "align_center" );
actionAlignVerticalCenter->setExclusiveGroup( "vertical_alignment" );
- actionSavePicture= new KAction( i18n("Save Picture..."), 0,
+ actionSavePicture= new TDEAction( i18n("Save Picture..."), 0,
TQT_TQOBJECT(this), TQT_SLOT( savePicture() ),
actionCollection(), "save_picture");
- actionAllowBgSpellCheck = new KToggleAction( i18n( "Autospellcheck" ), 0,
+ actionAllowBgSpellCheck = new TDEToggleAction( i18n( "Autospellcheck" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( autoSpellCheck() ),
actionCollection(), "tool_auto_spellcheck" );
- actionInsertFile= new KAction( i18n( "File..." ), 0,
+ actionInsertFile= new TDEAction( i18n( "File..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( insertFile() ),
actionCollection(), "insert_file" );
- actionImportStyle= new KAction( i18n( "Import Styles..." ), 0,
+ actionImportStyle= new TDEAction( i18n( "Import Styles..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( importStyle() ),
actionCollection(), "import_style" );
- actionSaveBackgroundPicture= new KAction( i18n( "Save Background Picture..." ), 0,
+ actionSaveBackgroundPicture= new TDEAction( i18n( "Save Background Picture..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT(backgroundPicture() ),
actionCollection(), "save_bgpicture" );
#if 0
- actionInsertDirectCursor = new KToggleAction( i18n( "Type Anywhere Cursor" ), 0,
+ actionInsertDirectCursor = new TDEToggleAction( i18n( "Type Anywhere Cursor" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( insertDirectCursor() ),
actionCollection(), "direct_cursor" );
#endif
- actionSpellIgnoreAll = new KAction( i18n( "Ignore All" ), 0,
+ actionSpellIgnoreAll = new TDEAction( i18n( "Ignore All" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotAddIgnoreAllWord() ),
actionCollection(), "ignore_all" );
- actionAddWordToPersonalDictionary=new KAction( i18n( "Add Word to Dictionary" ),0,
+ actionAddWordToPersonalDictionary=new TDEAction( i18n( "Add Word to Dictionary" ),0,
TQT_TQOBJECT(this), TQT_SLOT( addWordToDictionary() ),
actionCollection(), "add_word_to_dictionary" );
- actionCustomSlideShow = new KAction( i18n( "Custom Slide Show..." ), 0,
+ actionCustomSlideShow = new TDEAction( i18n( "Custom Slide Show..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( customSlideShow() ),
actionCollection(), "custom_slide_show" );
- actionDisplayObjectFromMasterPage = new KToggleAction( i18n( "Hide Object From Slide Master" ), 0,
+ actionDisplayObjectFromMasterPage = new TDEToggleAction( i18n( "Hide Object From Slide Master" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( displayObjectFromMasterPage() ),
actionCollection(), "display_object_from_master_page" );
actionDisplayObjectFromMasterPage->setCheckedState(i18n("Display Object From Slide Master"));
- actionDisplayBackgroundPage = new KToggleAction( i18n( "Hide Background" ), 0,
+ actionDisplayBackgroundPage = new TDEToggleAction( i18n( "Hide Background" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( displayBackground() ),
actionCollection(), "display_background" );
actionDisplayBackgroundPage->setCheckedState(i18n("Display Background"));
@@ -3617,11 +3617,11 @@ void KPrView::doAutomaticScreenPres()
void KPrView::updateReadWrite( bool readwrite )
{
// First disable or enable everything
- TQValueList<KAction*> actions = actionCollection()->actions();
+ TQValueList<TDEAction*> actions = actionCollection()->actions();
// Also grab actions from the document
actions += m_pKPresenterDoc->actionCollection()->actions();
- TQValueList<KAction*>::ConstIterator aIt = actions.begin();
- TQValueList<KAction*>::ConstIterator aEnd = actions.end();
+ TQValueList<TDEAction*>::ConstIterator aIt = actions.begin();
+ TQValueList<TDEAction*>::ConstIterator aEnd = actions.end();
for (; aIt != aEnd; ++aIt )
(*aIt)->setEnabled( readwrite );
@@ -4230,8 +4230,8 @@ void KPrView::openPopupMenuMenuPage( const TQPoint & _point )
{
if(!koDocument()->isReadWrite() || !factory())
return;
- TQPtrList<KAction> actionList= TQPtrList<KAction>();
- KActionSeparator *separator=new KActionSeparator();
+ TQPtrList<TDEAction> actionList= TQPtrList<TDEAction>();
+ TDEActionSeparator *separator=new TDEActionSeparator();
switch( m_canvas->activePage()->getBackType())
{
case BT_COLOR:
@@ -4721,7 +4721,7 @@ void KPrView::showCounter( KoParagCounter &c )
TQString styleStr("counterstyle_");
styleStr += TQString::number( c.style() );
//kdDebug(33001) << "KWView::showCounter styleStr=" << styleStr << endl;
- KToggleAction* act = static_cast<KToggleAction *>( actionCollection()->action( styleStr.latin1() ) );
+ TDEToggleAction* act = static_cast<TDEToggleAction *>( actionCollection()->action( styleStr.latin1() ) );
Q_ASSERT( act );
if ( act )
act->setChecked( true );
@@ -4819,13 +4819,13 @@ TQPopupMenu * KPrView::popupMenu( const TQString& name )
}
void KPrView::addVariableActions( int type, const TQStringList & texts,
- KActionMenu * parentMenu, const TQString & menuText )
+ TDEActionMenu * parentMenu, const TQString & menuText )
{
// Single items go directly into parentMenu.
// For multiple items we create a submenu.
if ( texts.count() > 1 && !menuText.isEmpty() )
{
- KActionMenu * subMenu = new KActionMenu( menuText, actionCollection() );
+ TDEActionMenu * subMenu = new TDEActionMenu( menuText, actionCollection() );
parentMenu->insert( subMenu );
parentMenu = subMenu;
}
@@ -4837,7 +4837,7 @@ void KPrView::addVariableActions( int type, const TQStringList & texts,
VariableDef v;
v.type = type;
v.subtype = i;
- KAction * act = new KAction( (*it), 0, TQT_TQOBJECT(this), TQT_SLOT( insertVariable() ),
+ TDEAction * act = new TDEAction( (*it), 0, TQT_TQOBJECT(this), TQT_SLOT( insertVariable() ),
actionCollection(), "var-action" );
m_variableDefMap.insert( act, v );
parentMenu->insert( act );
@@ -4847,11 +4847,11 @@ void KPrView::addVariableActions( int type, const TQStringList & texts,
void KPrView::refreshCustomMenu()
{
- KActionPtrList lst2 = actionCollection()->actions("custom-variable-action");
- TQValueList<KAction *> actions = lst2;
- TQValueList<KAction *>::ConstIterator it2 = lst2.begin();
- TQValueList<KAction *>::ConstIterator end = lst2.end();
- TQMap<TQString, KShortcut> shortCuts;
+ TDEActionPtrList lst2 = actionCollection()->actions("custom-variable-action");
+ TQValueList<TDEAction *> actions = lst2;
+ TQValueList<TDEAction *>::ConstIterator it2 = lst2.begin();
+ TQValueList<TDEAction *>::ConstIterator end = lst2.end();
+ TQMap<TQString, TDEShortcut> shortCuts;
for (; it2 != end; ++it2 )
{
@@ -4860,7 +4860,7 @@ void KPrView::refreshCustomMenu()
}
delete actionInsertCustom;
- actionInsertCustom = new KActionMenu( i18n( "&Custom" ),
+ actionInsertCustom = new TDEActionMenu( i18n( "&Custom" ),
actionCollection(), "insert_custom" );
actionInsertVariable->insert(actionInsertCustom, 0);
@@ -4868,7 +4868,7 @@ void KPrView::refreshCustomMenu()
actionInsertCustom->popupMenu()->clear();
TQPtrListIterator<KoVariable> it( m_pKPresenterDoc->getVariableCollection()->getVariables() );
- KAction * act=0;
+ TDEAction * act=0;
TQStringList lst;
TQString varName;
int i = 0;
@@ -4882,7 +4882,7 @@ void KPrView::refreshCustomMenu()
{
lst.append( varName );
TQCString name = TQString("custom-action_%1").arg(i).latin1();
- act = new KAction( varName, shortCuts[varName], TQT_TQOBJECT(this),
+ act = new TDEAction( varName, shortCuts[varName], TQT_TQOBJECT(this),
TQT_SLOT( insertCustomVariable() ), actionCollection(), name );
act->setGroup( "custom-variable-action" );
@@ -4895,7 +4895,7 @@ void KPrView::refreshCustomMenu()
if(state)
actionInsertCustom->popupMenu()->insertSeparator();
- act = new KAction( i18n("New..."), 0, TQT_TQOBJECT(this), TQT_SLOT( insertNewCustomVariable() ), actionCollection(),
+ act = new TDEAction( i18n("New..."), 0, TQT_TQOBJECT(this), TQT_SLOT( insertNewCustomVariable() ), actionCollection(),
TQString("custom-action_%1").arg(i).latin1() );
act->setGroup( "custom-variable-action" );
actionInsertCustom->insert( act );
@@ -4912,7 +4912,7 @@ void KPrView::insertCustomVariable()
KPrTextView *edit=m_canvas->currentTextObjectView();
if ( edit )
{
- KAction * act = (KAction *)(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender())));
+ TDEAction * act = (TDEAction *)(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender())));
edit->insertCustomVariable(act->text());
}
}
@@ -4992,7 +4992,7 @@ void KPrView::insertVariable()
KPrTextView *edit=m_canvas->currentTextObjectView();
if ( edit )
{
- KAction * act = (KAction *)(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender())));
+ TDEAction * act = (TDEAction *)(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender())));
VariableDefMap::ConstIterator it = m_variableDefMap.find( act );
if ( it == m_variableDefMap.end() )
kdWarning(33001) << "Action not found in m_variableDefMap." << endl;
@@ -5456,22 +5456,22 @@ void KPrView::updateStyleList()
// Generate list of styles
const TQStringList lst = m_pKPresenterDoc->styleCollection()->displayNameList();
const int pos = lst.findIndex( currentStyle );
- // Fill the combo - using a KSelectAction
+ // Fill the combo - using a TDESelectAction
actionFormatStyle->setItems( lst );
if ( pos > -1 )
actionFormatStyle->setCurrentItem( pos );
- // Fill the menu - using a KActionMenu, so that it's possible to bind keys
+ // Fill the menu - using a TDEActionMenu, so that it's possible to bind keys
// to individual actions
TQStringList lstWithAccels;
// Generate unique accelerators for the menu items
- KAccelGen::generate( lst, lstWithAccels );
- TQMap<TQString, KShortcut> shortCuts;
+ TDEAccelGen::generate( lst, lstWithAccels );
+ TQMap<TQString, TDEShortcut> shortCuts;
- KActionPtrList lst2 = actionCollection()->actions("styleList");
- TQValueList<KAction *> actions = lst2;
- TQValueList<KAction *>::ConstIterator it = lst2.begin();
- TQValueList<KAction *>::ConstIterator end = lst2.end();
+ TDEActionPtrList lst2 = actionCollection()->actions("styleList");
+ TQValueList<TDEAction *> actions = lst2;
+ TQValueList<TDEAction *>::ConstIterator it = lst2.begin();
+ TQValueList<TDEAction *>::ConstIterator end = lst2.end();
for (; it != end; ++it )
{
shortCuts.insert( TQString::fromUtf8( (*it)->name() ), (*it)->shortcut() );
@@ -5487,7 +5487,7 @@ void KPrView::updateStyleList()
if ( style )
{
TQString name = "paragstyle_" + style->name();
- KToggleAction* act = new KToggleAction( (*it),
+ TDEToggleAction* act = new TDEToggleAction( (*it),
shortCuts[name], TQT_TQOBJECT(this), TQT_SLOT( slotStyleSelected() ),
actionCollection(), name.utf8() );
act->setGroup( "styleList" );
@@ -6364,9 +6364,9 @@ void KPrView::spellAddAutoCorrect (const TQString & originalword, const TQString
m_pKPresenterDoc->getAutoFormat()->addAutoFormatEntry( originalword, newword );
}
-TQPtrList<KAction> KPrView::listOfResultOfCheckWord( const TQString &word )
+TQPtrList<TDEAction> KPrView::listOfResultOfCheckWord( const TQString &word )
{
- TQPtrList<KAction> listAction;
+ TQPtrList<TDEAction> listAction;
DefaultDictionary *dict = m_broker->defaultDictionary();
TQStringList lst = dict->suggest( word );
if ( !lst.contains( word ))
@@ -6376,7 +6376,7 @@ TQPtrList<KAction> KPrView::listOfResultOfCheckWord( const TQString &word )
{
if ( !(*it).isEmpty() ) // in case of removed subtypes or placeholders
{
- KAction * act = new KAction( (*it));
+ TDEAction * act = new TDEAction( (*it));
connect( act, TQT_SIGNAL(activated()), TQT_TQOBJECT(this), TQT_SLOT(slotCorrectWord()) );
listAction.append( act );
}
@@ -6388,7 +6388,7 @@ TQPtrList<KAction> KPrView::listOfResultOfCheckWord( const TQString &word )
void KPrView::slotCorrectWord()
{
- KAction * act = (KAction *)(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender())));
+ TDEAction * act = (TDEAction *)(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender())));
KPrTextView* edit = m_canvas->currentTextObjectView();
if ( edit )
{
diff --git a/kpresenter/KPrView.h b/kpresenter/KPrView.h
index 8c199bad..abb7ac59 100644
--- a/kpresenter/KPrView.h
+++ b/kpresenter/KPrView.h
@@ -59,10 +59,10 @@ class TQToolButton;
class KPrSideBar;
class KPrNoteBar;
-class KAction;
-class KActionMenu;
-class KToggleAction;
-class TKSelectColorAction;
+class TDEAction;
+class TDEActionMenu;
+class TDEToggleAction;
+class TTDESelectColorAction;
class KoPartSelectAction;
class KoPicture;
class KoParagStyle;
@@ -77,12 +77,12 @@ class KoTextZoomHandler;
class KCommand;
class KMacroCommand;
-class KFontSizeAction;
+class TDEFontSizeAction;
class KColorAction;
-class KSelectAction;
-class KFontAction;
+class TDESelectAction;
+class TDEFontAction;
class KoParagCounter;
-class KActionMenu;
+class TDEActionMenu;
class KoSearchContext;
class KPrFindReplace;
class KPrCanvas;
@@ -171,7 +171,7 @@ public:
void insertFile(const TQString &path);
void testAndCloseAllTextObjectProtectedContent();
void updateRulerInProtectContentMode();
- TQPtrList<KAction> listOfResultOfCheckWord( const TQString &word );
+ TQPtrList<TDEAction> listOfResultOfCheckWord( const TQString &word );
/**
* Returns the KPresenter global KSpell2 Broker object.
@@ -528,8 +528,8 @@ public:
bool getGUnbalanced() const { return gUnbalanced; }
int getGXFactor() const { return gXFactor; }
int getGYFactor() const { return gYFactor; }
- TKSelectColorAction* getActionBrushColor() const { return actionBrushColor; }
- TKSelectColorAction* getActionPenColor() const { return actionPenColor; }
+ TTDESelectColorAction* getActionBrushColor() const { return actionBrushColor; }
+ TTDESelectColorAction* getActionPenColor() const { return actionPenColor; }
void setPieType(PieType _pieType) { pieType = _pieType; }
void setPieAngle(int _pieAngle) { pieAngle = _pieAngle; }
@@ -632,9 +632,9 @@ public:
KPrNoteBar *getNoteBar() const { return notebar; }
// Used by Page to plug/unplug the datatool actions
- TQPtrList<KAction>& actionList() { return m_actionList; }
+ TQPtrList<TDEAction>& actionList() { return m_actionList; }
// Used by Page to plug/unplug the variable actions
- TQPtrList<KAction> &variableActionList() { return m_variableActionList; }
+ TQPtrList<TDEAction> &variableActionList() { return m_variableActionList; }
// for Polygon object
bool getCheckConcavePolygon() const { return checkConcavePolygon; }
@@ -781,7 +781,7 @@ protected:
virtual void updateReadWrite( bool readwrite );
void addVariableActions( int type, const TQStringList & texts,
- KActionMenu * parentMenu, const TQString & menuText );
+ TDEActionMenu * parentMenu, const TQString & menuText );
void showParagraphDialog( int initialPage = -1, double initialTabPos = 0.0 );
@@ -832,8 +832,8 @@ private:
// right button popup menus
TQPopupMenu *rb_lbegin, *rb_lend;
TQPopupMenu *m_arrangeObjectsPopup;
- TQPtrList<KAction> m_actionList; // for the kodatatools
- TQPtrList<KAction> m_variableActionList;
+ TQPtrList<TDEAction> m_actionList; // for the kodatatools
+ TQPtrList<TDEAction> m_variableActionList;
// scrollbars
TQScrollBar *vert, *horz;
@@ -906,160 +906,160 @@ private:
KStatusBarLabel* m_sbZoomLabel;
// actions
- KAction *actionEditCut;
- KAction *actionEditCustomVars;
- KAction *actionEditCopy;
- KAction *actionEditPaste;
- KAction *actionEditDelete;
- KAction *actionEditSelectAll;
- KAction *actionEditDeSelectAll;
- KAction *actionEditCopyPage;
- KAction *actionEditDuplicatePage;
- KAction *actionEditDelPage;
-
- KToggleAction *actionViewShowSideBar;
- KToggleAction *actionViewShowNoteBar;
- KToggleAction *actionViewSlideMaster;
-
- KToggleAction *actionViewShowGuideLine;
-
- KToggleAction *actionViewFormattingChars;
- KToggleAction *actionViewShowGrid;
- KToggleAction *actionViewSnapToGrid;
-
- KAction *actionInsertPage;
- KAction *actionInsertPicture;
-
- KToggleAction *actionToolsMouse;
- KToggleAction *actionToolsRotate;
- KToggleAction *actionToolsZoom;
- KToggleAction *actionToolsLine;
- KToggleAction *actionToolsRectangle;
- KToggleAction *actionToolsCircleOrEllipse;
- KToggleAction *actionToolsPie;
- KToggleAction *actionToolsText;
- KToggleAction *actionToolsAutoform;
- KToggleAction *actionToolsDiagramm;
- KToggleAction *actionToolsTable;
- KToggleAction *actionToolsFormula;
- KToggleAction *actionToolsFreehand;
- KToggleAction *actionToolsPolyline;
- KToggleAction *actionToolsQuadricBezierCurve;
- KToggleAction *actionToolsCubicBezierCurve;
- KToggleAction *actionToolsConvexOrConcavePolygon;
- KToggleAction *actionToolsClosedFreehand;
- KToggleAction *actionToolsClosedPolyline;
- KToggleAction *actionToolsClosedQuadricBezierCurve;
- KToggleAction *actionToolsClosedCubicBezierCurve;
+ TDEAction *actionEditCut;
+ TDEAction *actionEditCustomVars;
+ TDEAction *actionEditCopy;
+ TDEAction *actionEditPaste;
+ TDEAction *actionEditDelete;
+ TDEAction *actionEditSelectAll;
+ TDEAction *actionEditDeSelectAll;
+ TDEAction *actionEditCopyPage;
+ TDEAction *actionEditDuplicatePage;
+ TDEAction *actionEditDelPage;
+
+ TDEToggleAction *actionViewShowSideBar;
+ TDEToggleAction *actionViewShowNoteBar;
+ TDEToggleAction *actionViewSlideMaster;
+
+ TDEToggleAction *actionViewShowGuideLine;
+
+ TDEToggleAction *actionViewFormattingChars;
+ TDEToggleAction *actionViewShowGrid;
+ TDEToggleAction *actionViewSnapToGrid;
+
+ TDEAction *actionInsertPage;
+ TDEAction *actionInsertPicture;
+
+ TDEToggleAction *actionToolsMouse;
+ TDEToggleAction *actionToolsRotate;
+ TDEToggleAction *actionToolsZoom;
+ TDEToggleAction *actionToolsLine;
+ TDEToggleAction *actionToolsRectangle;
+ TDEToggleAction *actionToolsCircleOrEllipse;
+ TDEToggleAction *actionToolsPie;
+ TDEToggleAction *actionToolsText;
+ TDEToggleAction *actionToolsAutoform;
+ TDEToggleAction *actionToolsDiagramm;
+ TDEToggleAction *actionToolsTable;
+ TDEToggleAction *actionToolsFormula;
+ TDEToggleAction *actionToolsFreehand;
+ TDEToggleAction *actionToolsPolyline;
+ TDEToggleAction *actionToolsQuadricBezierCurve;
+ TDEToggleAction *actionToolsCubicBezierCurve;
+ TDEToggleAction *actionToolsConvexOrConcavePolygon;
+ TDEToggleAction *actionToolsClosedFreehand;
+ TDEToggleAction *actionToolsClosedPolyline;
+ TDEToggleAction *actionToolsClosedQuadricBezierCurve;
+ TDEToggleAction *actionToolsClosedCubicBezierCurve;
KoPartSelectAction *actionToolsObject;
- KActionMenu *actionToolsLinePopup;
- KActionMenu *actionToolsShapePopup;
- KActionMenu *actionToolsClosedLinePopup;
-
- KAction *actionTextFont;
- KFontSizeAction *actionTextFontSize;
- KFontAction *actionTextFontFamily;
- KToggleAction *actionTextAlignLeft;
- KToggleAction *actionTextAlignCenter;
- KToggleAction *actionTextAlignRight;
- KToggleAction *actionTextAlignBlock;
-
- KActionMenu *actionFormatBullet;
- KActionMenu *actionFormatNumber;
-
-
- KAction *actionTextDepthPlus;
- KAction *actionTextDepthMinus;
- KAction *actionTextExtentCont2Height;
- KAction *actionTextExtendObj2Cont;
- KToggleAction *actionTextBold;
- KToggleAction *actionTextItalic;
- KToggleAction *actionTextUnderline;
- KToggleAction *actionFormatStrikeOut;
- KAction *actionTextInsertPageNum;
-
- KAction *actionExtraProperties;
- KAction *actionExtraRaise;
- KAction *actionExtraLower;
-
- KAction *actionExtraBringForward;
- KAction *actionExtraSendBackward;
- KActionMenu *actionExtraArrangePopup;
-
- KAction *actionExtraRotate;
- KAction *actionExtraShadow;
- KActionMenu *actionExtraAlignObjsPopup;
- KAction *actionExtraAlignObjLeft;
- KAction *actionExtraAlignObjCenterH;
- KAction *actionExtraAlignObjRight;
- KAction *actionExtraAlignObjTop;
- KAction *actionExtraAlignObjCenterV;
- KAction *actionExtraAlignObjBottom;
- KAction *actionExtraBackground;
- KAction *actionExtraLayout;
- KAction *actionExtraConfigure;
- KAction *actionExtraWebPres;
- KAction *actionExtraMSPres;
- KAction *actionExtraCreateTemplate;
- KAction *actionExtraLineBegin;
- KAction *actionExtraLineEnd;
- KAction *actionExtraGroup;
- KAction *actionExtraUnGroup;
+ TDEActionMenu *actionToolsLinePopup;
+ TDEActionMenu *actionToolsShapePopup;
+ TDEActionMenu *actionToolsClosedLinePopup;
+
+ TDEAction *actionTextFont;
+ TDEFontSizeAction *actionTextFontSize;
+ TDEFontAction *actionTextFontFamily;
+ TDEToggleAction *actionTextAlignLeft;
+ TDEToggleAction *actionTextAlignCenter;
+ TDEToggleAction *actionTextAlignRight;
+ TDEToggleAction *actionTextAlignBlock;
+
+ TDEActionMenu *actionFormatBullet;
+ TDEActionMenu *actionFormatNumber;
+
+
+ TDEAction *actionTextDepthPlus;
+ TDEAction *actionTextDepthMinus;
+ TDEAction *actionTextExtentCont2Height;
+ TDEAction *actionTextExtendObj2Cont;
+ TDEToggleAction *actionTextBold;
+ TDEToggleAction *actionTextItalic;
+ TDEToggleAction *actionTextUnderline;
+ TDEToggleAction *actionFormatStrikeOut;
+ TDEAction *actionTextInsertPageNum;
+
+ TDEAction *actionExtraProperties;
+ TDEAction *actionExtraRaise;
+ TDEAction *actionExtraLower;
+
+ TDEAction *actionExtraBringForward;
+ TDEAction *actionExtraSendBackward;
+ TDEActionMenu *actionExtraArrangePopup;
+
+ TDEAction *actionExtraRotate;
+ TDEAction *actionExtraShadow;
+ TDEActionMenu *actionExtraAlignObjsPopup;
+ TDEAction *actionExtraAlignObjLeft;
+ TDEAction *actionExtraAlignObjCenterH;
+ TDEAction *actionExtraAlignObjRight;
+ TDEAction *actionExtraAlignObjTop;
+ TDEAction *actionExtraAlignObjCenterV;
+ TDEAction *actionExtraAlignObjBottom;
+ TDEAction *actionExtraBackground;
+ TDEAction *actionExtraLayout;
+ TDEAction *actionExtraConfigure;
+ TDEAction *actionExtraWebPres;
+ TDEAction *actionExtraMSPres;
+ TDEAction *actionExtraCreateTemplate;
+ TDEAction *actionExtraLineBegin;
+ TDEAction *actionExtraLineEnd;
+ TDEAction *actionExtraGroup;
+ TDEAction *actionExtraUnGroup;
KoLineStyleAction *actionExtraPenStyle;
KoLineWidthAction *actionExtraPenWidth;
- KAction *actionScreenConfigPages;
- KAction *actionScreenAssignEffect;
- KAction *actionScreenTransEffect;
- KAction *actionScreenStart;
- KAction *actionScreenStartFromFirst;
- KAction *actionScreenStop;
- KAction *actionScreenPause;
- KAction *actionScreenFirst;
- KAction *actionScreenPrev;
- KAction *actionScreenNext;
- KAction *actionScreenLast;
- KAction *actionScreenSkip;
+ TDEAction *actionScreenConfigPages;
+ TDEAction *actionScreenAssignEffect;
+ TDEAction *actionScreenTransEffect;
+ TDEAction *actionScreenStart;
+ TDEAction *actionScreenStartFromFirst;
+ TDEAction *actionScreenStop;
+ TDEAction *actionScreenPause;
+ TDEAction *actionScreenFirst;
+ TDEAction *actionScreenPrev;
+ TDEAction *actionScreenNext;
+ TDEAction *actionScreenLast;
+ TDEAction *actionScreenSkip;
- KAction *actionEditFind;
- KAction *actionEditFindNext;
- KAction *actionEditFindPrevious;
- KAction *actionEditReplace;
+ TDEAction *actionEditFind;
+ TDEAction *actionEditFindNext;
+ TDEAction *actionEditFindPrevious;
+ TDEAction *actionEditReplace;
- KAction *actionCustomSlideShow;
+ TDEAction *actionCustomSlideShow;
- KAction *actionColorBar;
- KAction *actionExtraDefaultTemplate;
+ TDEAction *actionColorBar;
+ TDEAction *actionExtraDefaultTemplate;
- TKSelectColorAction* actionBrushColor;
- TKSelectColorAction* actionPenColor;
- TKSelectColorAction* actionTextColor;
+ TTDESelectColorAction* actionBrushColor;
+ TTDESelectColorAction* actionPenColor;
+ TTDESelectColorAction* actionTextColor;
- KAction *actionResizeTextObject;
- KAction *actionExtendObjectHeight;
- KAction *actionObjectProperties;
+ TDEAction *actionResizeTextObject;
+ TDEAction *actionExtendObjectHeight;
+ TDEAction *actionObjectProperties;
- KAction *actionRenamePage;
+ TDEAction *actionRenamePage;
- KAction *actionPicOriginalSize;
- KAction *actionPic640x480;
- KAction *actionPic800x600;
- KAction *actionPic1024x768;
- KAction *actionPic1280x1024;
- KAction *actionPic1600x1200;
- KAction *actionChangePic;
- KAction *actionExtraSpellCheck;
- KAction *actionFormatDefault;
+ TDEAction *actionPicOriginalSize;
+ TDEAction *actionPic640x480;
+ TDEAction *actionPic800x600;
+ TDEAction *actionPic1024x768;
+ TDEAction *actionPic1280x1024;
+ TDEAction *actionPic1600x1200;
+ TDEAction *actionChangePic;
+ TDEAction *actionExtraSpellCheck;
+ TDEAction *actionFormatDefault;
- KAction *actionImageEffect;
+ TDEAction *actionImageEffect;
- KAction *actionInsertComment;
- KAction *actionEditComment;
- KAction *actionRemoveComment;
- KAction *actionCopyTextOfComment;
+ TDEAction *actionInsertComment;
+ TDEAction *actionEditComment;
+ TDEAction *actionRemoveComment;
+ TDEAction *actionCopyTextOfComment;
- KAction *actionImportStyle;
+ TDEAction *actionImportStyle;
DCOPObject *dcop;
@@ -1069,79 +1069,79 @@ private:
TQSplitter *splitter;
PageBase *pageBase;
- KToggleAction *actionFormatSuper;
- KToggleAction *actionFormatSub;
+ TDEToggleAction *actionFormatSuper;
+ TDEToggleAction *actionFormatSub;
- KToggleAction *m_actionExtraHeader;
- KToggleAction *m_actionExtraFooter;
+ TDEToggleAction *m_actionExtraHeader;
+ TDEToggleAction *m_actionExtraFooter;
- KAction* actionInsertSpecialChar;
- KAction *actionInsertLink;
+ TDEAction* actionInsertSpecialChar;
+ TDEAction *actionInsertLink;
- KAction * actionChangeLink;
- KAction *actionCopyLink;
- KAction *actionRemoveLink;
+ TDEAction * actionChangeLink;
+ TDEAction *actionCopyLink;
+ TDEAction *actionRemoveLink;
- KAction *actionAddLinkToBookmak;
- KAction *actionFormatParag;
- KAction *actionOpenLink;
- KAction *actionIncreaseFontSize;
- KAction *actionDecreaseFontSize;
- KAction *actionChangeCase;
- KAction *actionRefreshAllVariable;
+ TDEAction *actionAddLinkToBookmak;
+ TDEAction *actionFormatParag;
+ TDEAction *actionOpenLink;
+ TDEAction *actionIncreaseFontSize;
+ TDEAction *actionDecreaseFontSize;
+ TDEAction *actionChangeCase;
+ TDEAction *actionRefreshAllVariable;
- KSelectAction *actionViewZoom;
+ TDESelectAction *actionViewZoom;
- KSelectAction *actionFormatStyle;
+ TDESelectAction *actionFormatStyle;
- KToggleAction *actionAllowAutoFormat;
+ TDEToggleAction *actionAllowAutoFormat;
- KToggleAction *actionDisplayObjectFromMasterPage;
+ TDEToggleAction *actionDisplayObjectFromMasterPage;
- KToggleAction *actionDisplayBackgroundPage;
+ TDEToggleAction *actionDisplayBackgroundPage;
- KAction *actionFormatStylist;
+ TDEAction *actionFormatStylist;
- KAction *actionAddGuideLine;
+ TDEAction *actionAddGuideLine;
- KAction *actionConfigureCompletion;
+ TDEAction *actionConfigureCompletion;
- KAction *actionZoomMinus;
- KAction *actionZoomPageWidth;
- KAction *actionZoomEntirePage;
- KAction *actionZoomPlus;
- KAction *actionZoomSelectedObject;
- KAction *actionZoomPageHeight;
- KAction *actionZoomAllObject;
+ TDEAction *actionZoomMinus;
+ TDEAction *actionZoomPageWidth;
+ TDEAction *actionZoomEntirePage;
+ TDEAction *actionZoomPlus;
+ TDEAction *actionZoomSelectedObject;
+ TDEAction *actionZoomPageHeight;
+ TDEAction *actionZoomAllObject;
- KAction *actionFlipHorizontal;
- KAction *actionFlipVertical;
- KAction *actionCloseObject;
+ TDEAction *actionFlipHorizontal;
+ TDEAction *actionFlipVertical;
+ TDEAction *actionCloseObject;
- KAction *actionDuplicateObj;
- KAction *actionApplyAutoFormat;
+ TDEAction *actionDuplicateObj;
+ TDEAction *actionApplyAutoFormat;
- KAction *actionCreateStyleFromSelection;
+ TDEAction *actionCreateStyleFromSelection;
- KAction *actionSavePicture;
+ TDEAction *actionSavePicture;
- KAction *actionSaveBackgroundPicture;
+ TDEAction *actionSaveBackgroundPicture;
- KAction *actionInsertFile;
+ TDEAction *actionInsertFile;
- KAction *actionSpellIgnoreAll;
+ TDEAction *actionSpellIgnoreAll;
- KToggleAction *actionAlignVerticalTop;
- KToggleAction *actionAlignVerticalBottom;
- KToggleAction *actionAlignVerticalCenter;
+ TDEToggleAction *actionAlignVerticalTop;
+ TDEToggleAction *actionAlignVerticalBottom;
+ TDEToggleAction *actionAlignVerticalCenter;
- KToggleAction *actionAllowBgSpellCheck;
- KAction *actionEditCustomVarsEdit;
- KActionMenu *actionFormatStyleMenu;
- KToggleAction *actionInsertDirectCursor;
+ TDEToggleAction *actionAllowBgSpellCheck;
+ TDEAction *actionEditCustomVarsEdit;
+ TDEActionMenu *actionFormatStyleMenu;
+ TDEToggleAction *actionInsertDirectCursor;
- KAction *actionAddWordToPersonalDictionary;
+ TDEAction *actionAddWordToPersonalDictionary;
/// timer for automatic presentation mode
TQTimer m_autoPresTimer;
@@ -1205,14 +1205,14 @@ private:
- KActionMenu *actionInsertVariable;
- KActionMenu *actionInsertCustom;
+ TDEActionMenu *actionInsertVariable;
+ TDEActionMenu *actionInsertCustom;
struct VariableDef {
int type;
int subtype;
};
- typedef TQMap<KAction *, VariableDef> VariableDefMap;
+ typedef TQMap<TDEAction *, VariableDef> VariableDefMap;
VariableDefMap m_variableDefMap;
KoSearchContext *m_searchEntry, *m_replaceEntry;
diff --git a/kpresenter/KPrWebPresentation.cpp b/kpresenter/KPrWebPresentation.cpp
index d87a82c4..9dd7e2f8 100644
--- a/kpresenter/KPrWebPresentation.cpp
+++ b/kpresenter/KPrWebPresentation.cpp
@@ -932,7 +932,7 @@ void KPrWebPresentationWizard::setupPage4()
connect( slideTitle, TQT_SIGNAL( textChanged( const TQString & ) ), this,
TQT_SLOT( slideTitleChanged( const TQString & ) ) );
- slideTitles = new KListView( canvas );
+ slideTitles = new TDEListView( canvas );
layout->addMultiCellWidget( slideTitles, 2, 2, 0, 1 );
slideTitles->addColumn( i18n( "No." ) );
slideTitles->addColumn( i18n( "Slide Title" ) );
@@ -945,7 +945,7 @@ void KPrWebPresentationWizard::setupPage4()
TQValueList<KPrWebPresentation::SlideInfo> infos = webPres.getSlideInfos();
for ( int i = infos.count() - 1; i >= 0; --i ) {
- KListViewItem *item = new KListViewItem( slideTitles );
+ TDEListViewItem *item = new TDEListViewItem( slideTitles );
item->setText( 0, TQString::number( i + 1 ) );
//kdDebug(33001) << "KPrWebPresentationWizard::setupPage3 " << infos[ i ].slideTitle << endl;
item->setText( 1, infos[ i ].slideTitle );
diff --git a/kpresenter/KPrWebPresentation.h b/kpresenter/KPrWebPresentation.h
index 99b90ef6..3c7aba93 100644
--- a/kpresenter/KPrWebPresentation.h
+++ b/kpresenter/KPrWebPresentation.h
@@ -32,7 +32,7 @@ class KPrView;
class KURLRequester;
class KColorButton;
-class KListView;
+class TDEListView;
class KIntNumInput;
class KLineEdit;
class KComboBox;
@@ -179,7 +179,7 @@ protected:
KComboBox *encoding, *doctype;
KIntNumInput *zoom, *timeBetweenSlides; // PAU
KURLRequester *path;
- KListView *slideTitles;
+ TDEListView *slideTitles;
KLineEdit *slideTitle;
protected slots:
diff --git a/kpresenter/KPrSideBar.cpp b/kpresenter/KPrSideBar.cpp
index 715bdf02..29d56561 100644
--- a/kpresenter/KPrSideBar.cpp
+++ b/kpresenter/KPrSideBar.cpp
@@ -89,11 +89,11 @@ private:
};
-class OutlineSlideItem: public KListViewItem
+class OutlineSlideItem: public TDEListViewItem
{
public:
- OutlineSlideItem( KListView * parent, KPrPage* page, bool _masterPage );
- OutlineSlideItem( KListView * parent, OutlineSlideItem *after, KPrPage* page, bool _masterPage );
+ OutlineSlideItem( TDEListView * parent, KPrPage* page, bool _masterPage );
+ OutlineSlideItem( TDEListView * parent, OutlineSlideItem *after, KPrPage* page, bool _masterPage );
KPrPage* page() const { return m_page; }
@@ -107,7 +107,7 @@ private:
bool m_masterPage;
};
-class OutlineObjectItem: public KListViewItem
+class OutlineObjectItem: public TDEListViewItem
{
public:
OutlineObjectItem( OutlineSlideItem * parent, KPrObject* object,
@@ -577,16 +577,16 @@ void KPrThumbBar::slotRefreshItems()
refreshItems();
}
-OutlineSlideItem::OutlineSlideItem( KListView* parent, KPrPage* _page, bool _masterPage )
- : KListViewItem( parent ), m_page( _page ), m_masterPage( _masterPage )
+OutlineSlideItem::OutlineSlideItem( TDEListView* parent, KPrPage* _page, bool _masterPage )
+ : TDEListViewItem( parent ), m_page( _page ), m_masterPage( _masterPage )
{
setDragEnabled(true);
setPage( _page );
setPixmap( 0, KPBarIcon( "slide" ) );
}
-OutlineSlideItem::OutlineSlideItem( KListView* parent, OutlineSlideItem * after, KPrPage* _page, bool _masterPage )
- : KListViewItem( parent, after ), m_page( _page ), m_masterPage( _masterPage )
+OutlineSlideItem::OutlineSlideItem( TDEListView* parent, OutlineSlideItem * after, KPrPage* _page, bool _masterPage )
+ : TDEListViewItem( parent, after ), m_page( _page ), m_masterPage( _masterPage )
{
setDragEnabled(true);
setPage( _page );
@@ -678,7 +678,7 @@ void OutlineSlideItem::updateTitle()
OutlineObjectItem::OutlineObjectItem( OutlineSlideItem* parent, KPrObject* _object,
const TQString& name )
- : KListViewItem( parent ), m_object( _object )
+ : TDEListViewItem( parent ), m_object( _object )
{
setObject( m_object );
setDragEnabled( false );
@@ -756,7 +756,7 @@ void OutlineObjectItem::setObject( KPrObject* object )
}
KPrOutline::KPrOutline( TQWidget *parent, KPrDocument *d, KPrView *v )
- : KListView( parent ), KPrSideBarBase( d, v)
+ : TDEListView( parent ), KPrSideBarBase( d, v)
{
rebuildItems();
setSorting( -1 );
@@ -767,8 +767,8 @@ KPrOutline::KPrOutline( TQWidget *parent, KPrDocument *d, KPrView *v )
connect( this, TQT_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQT_SLOT( itemClicked( TQListViewItem * ) ) );
connect( this, TQT_SIGNAL( rightButtonPressed( TQListViewItem *, const TQPoint &, int ) ),
this, TQT_SLOT( rightButtonPressed( TQListViewItem *, const TQPoint &, int ) ) );
- connect( this, TQT_SIGNAL( contextMenu( KListView*, TQListViewItem*, const TQPoint& ) ),
- this, TQT_SLOT( slotContextMenu( KListView*, TQListViewItem*, const TQPoint&) ) );
+ connect( this, TQT_SIGNAL( contextMenu( TDEListView*, TQListViewItem*, const TQPoint& ) ),
+ this, TQT_SLOT( slotContextMenu( TDEListView*, TQListViewItem*, const TQPoint&) ) );
connect( this, TQT_SIGNAL( doubleClicked ( TQListViewItem * )),
this, TQT_SLOT(renamePageTitle()));
@@ -883,7 +883,7 @@ void KPrOutline::moveItem( int oldPos, int newPos )
item->updateTitle();
}
- KListView::moveItem( itemToMove, 0, itemAfter );
+ TDEListView::moveItem( itemToMove, 0, itemAfter );
}
void KPrOutline::removeItem( int pos )
@@ -954,7 +954,7 @@ void KPrOutline::slotDropped( TQDropEvent * /* e */, TQListViewItem *parent, TQL
if ( parent )
return;
// This code is taken from KListView
for (TQListViewItem *i = firstChild(), *iNext = 0; i != 0; i = iNext)
{
iNext = i->itemBelow();
@@ -1000,7 +1000,7 @@ void KPrOutline::setCurrentPage( int pg )
void KPrOutline::contentsDropEvent( TQDropEvent *e )
{
disconnect( this, TQT_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQT_SLOT( itemClicked( TQListViewItem * ) ) );
- KListView::contentsDropEvent( e );
+ TDEListView::contentsDropEvent( e );
connect( this, TQT_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQT_SLOT( itemClicked( TQListViewItem * ) ) );
}
@@ -1058,7 +1058,7 @@ void KPrOutline::rightButtonPressed( TQListViewItem *, const TQPoint &pnt, int )
}
}
-void KPrOutline::slotContextMenu( KListView*, TQListViewItem* item, const TQPoint& p )
+void KPrOutline::slotContextMenu( TDEListView*, TQListViewItem* item, const TQPoint& p )
{
rightButtonPressed( item, p, 0 );
}
@@ -1105,7 +1105,7 @@ TQDragObject* KPrOutline::dragObject()
return 0;
}
- return KListView::dragObject();
+ return TDEListView::dragObject();
}
#include "KPrSideBar.moc"
@@ -954,7 +954,7 @@ void KPrOutline::slotDropped( TQDropEvent * /* e */, TQListViewItem *parent, TQL
if ( parent )
return;
- // This code is taken from KListView
+ // This code is taken from TDEListView
for (TQListViewItem *i = firstChild(), *iNext = 0; i != 0; i = iNext)
{